/* list-view-row.c generated by valac 0.32.0.73-ab1d1, the Vala compiler
 * generated from list-view-row.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_LIST_VIEW_ROW (boxes_list_view_row_get_type ())
#define BOXES_LIST_VIEW_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIST_VIEW_ROW, BoxesListViewRow))
#define BOXES_LIST_VIEW_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIST_VIEW_ROW, BoxesListViewRowClass))
#define BOXES_IS_LIST_VIEW_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIST_VIEW_ROW))
#define BOXES_IS_LIST_VIEW_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIST_VIEW_ROW))
#define BOXES_LIST_VIEW_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIST_VIEW_ROW, BoxesListViewRowClass))

typedef struct _BoxesListViewRow BoxesListViewRow;
typedef struct _BoxesListViewRowClass BoxesListViewRowClass;
typedef struct _BoxesListViewRowPrivate BoxesListViewRowPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE_THUMBNAILER (boxes_machine_thumbnailer_get_type ())
#define BOXES_MACHINE_THUMBNAILER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailer))
#define BOXES_MACHINE_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailerClass))
#define BOXES_IS_MACHINE_THUMBNAILER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE_THUMBNAILER))
#define BOXES_IS_MACHINE_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE_THUMBNAILER))
#define BOXES_MACHINE_THUMBNAILER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE_THUMBNAILER, BoxesMachineThumbnailerClass))

typedef struct _BoxesMachineThumbnailer BoxesMachineThumbnailer;
typedef struct _BoxesMachineThumbnailerClass BoxesMachineThumbnailerClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_REMOTE_MACHINE (boxes_remote_machine_get_type ())
#define BOXES_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachine))
#define BOXES_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))
#define BOXES_IS_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_IS_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_REMOTE_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))

typedef struct _BoxesRemoteMachine BoxesRemoteMachine;
typedef struct _BoxesRemoteMachineClass BoxesRemoteMachineClass;

struct _BoxesListViewRow {
	GtkBox parent_instance;
	BoxesListViewRowPrivate * priv;
	gboolean _selection_mode;
	gboolean _selected;
};

struct _BoxesListViewRowClass {
	GtkBoxClass parent_class;
};

struct _BoxesListViewRowPrivate {
	BoxesCollectionItem* _item;
	GtkCheckButton* selection_button;
	GtkStack* stack;
	GtkImage* thumbnail;
	GtkSpinner* spinner;
	GtkImage* favorite;
	GtkLabel* machine_name;
	GtkLabel* info_label;
	GtkLabel* status_label;
	BoxesMachineThumbnailer* thumbnailer;
	GBinding* selected_binding;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*clone) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*clone_finish) (BoxesMachine* self, GAsyncResult* _res_);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_can_restart) (BoxesMachine* self);
	gboolean (*get_can_clone) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};


static gpointer boxes_list_view_row_parent_class = NULL;

GType boxes_list_view_row_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_thumbnailer_get_type (void) G_GNUC_CONST;
#define BOXES_LIST_VIEW_ROW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIST_VIEW_ROW, BoxesListViewRowPrivate))
enum  {
	BOXES_LIST_VIEW_ROW_DUMMY_PROPERTY,
	BOXES_LIST_VIEW_ROW_SELECTION_MODE,
	BOXES_LIST_VIEW_ROW_SELECTED,
	BOXES_LIST_VIEW_ROW_ITEM
};
#define BOXES_LIST_VIEW_ROW_SCREENSHOT_WIDTH 60
#define BOXES_LIST_VIEW_ROW_SCREENSHOT_HEIGHT 45
#define BOXES_LIST_VIEW_ROW_CENTERED_EMBLEM_SIZE 16
#define BOXES_LIST_VIEW_ROW_EMBLEM_SIZE 16
BoxesListViewRow* boxes_list_view_row_new (BoxesCollectionItem* item);
BoxesListViewRow* boxes_list_view_row_construct (GType object_type, BoxesCollectionItem* item);
static void boxes_list_view_row_set_item (BoxesListViewRow* self, BoxesCollectionItem* value);
GType boxes_machine_get_type (void) G_GNUC_CONST;
static BoxesMachine* boxes_list_view_row_get_machine (BoxesListViewRow* self);
BoxesMachineThumbnailer* boxes_machine_thumbnailer_new (BoxesMachine* machine, gint width, gint height, gint centred_emblem_size, gint emblem_size, GdkRGBA* border_color, GdkRGBA* background_color);
BoxesMachineThumbnailer* boxes_machine_thumbnailer_construct (GType object_type, BoxesMachine* machine, gint width, gint height, gint centred_emblem_size, gint emblem_size, GdkRGBA* border_color, GdkRGBA* background_color);
void boxes_machine_thumbnailer_set_favorite_emblem_enabled (BoxesMachineThumbnailer* self, gboolean value);
static void __lambda181_ (BoxesListViewRow* self);
GdkPixbuf* boxes_machine_thumbnailer_get_thumbnail (BoxesMachineThumbnailer* self);
static void ___lambda181__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void boxes_list_view_row_update_favorite (BoxesListViewRow* self);
static void _boxes_list_view_row_update_favorite_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_list_view_row_update_thumbnail (BoxesListViewRow* self);
static void _boxes_list_view_row_update_thumbnail_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_list_view_row_update_info (BoxesListViewRow* self);
static void _boxes_list_view_row_update_info_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_list_view_row_update_status (BoxesListViewRow* self);
static void _boxes_list_view_row_update_status_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gboolean boxes_machine_get_under_construction (BoxesMachine* self);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
const gchar* boxes_machine_get_info (BoxesMachine* self);
GType boxes_remote_machine_get_type (void) G_GNUC_CONST;
static void boxes_list_view_row_update_status_label_style (BoxesListViewRow* self, gboolean dim);
gboolean boxes_machine_get_is_connected (BoxesMachine* self);
gboolean boxes_machine_get_is_on (BoxesMachine* self);
const gchar* boxes_machine_get_status (BoxesMachine* self);
gboolean boxes_machine_get_is_running (BoxesMachine* self);
gboolean boxes_list_view_row_get_selection_mode (BoxesListViewRow* self);
void boxes_list_view_row_set_selection_mode (BoxesListViewRow* self, gboolean value);
void boxes_list_view_row_set_selected (BoxesListViewRow* self, gboolean value);
gboolean boxes_list_view_row_get_selected (BoxesListViewRow* self);
BoxesCollectionItem* boxes_list_view_row_get_item (BoxesListViewRow* self);
static void boxes_list_view_row_finalize (GObject* obj);
static void _vala_boxes_list_view_row_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_list_view_row_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

const GdkRGBA BOXES_LIST_VIEW_ROW_FRAME_BORDER_COLOR = {0x81 / 255.0, 0x85 / 255.0, 0x84 / 255.0, 1.0};
const GdkRGBA BOXES_LIST_VIEW_ROW_FRAME_BACKGROUND_COLOR = {0x4b / 255.0, 0x50 / 255.0, 0x50 / 255.0, 1.0};

static void __lambda181_ (BoxesListViewRow* self) {
	GtkImage* _tmp0_ = NULL;
	BoxesMachineThumbnailer* _tmp1_ = NULL;
	GdkPixbuf* _tmp2_ = NULL;
	GdkPixbuf* _tmp3_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = self->priv->thumbnail;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp1_ = self->priv->thumbnailer;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp2_ = boxes_machine_thumbnailer_get_thumbnail (_tmp1_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp3_ = _tmp2_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_image_set_from_pixbuf (_tmp0_, _tmp3_);
#line 287 "list-view-row.c"
}


static void ___lambda181__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	__lambda181_ ((BoxesListViewRow*) self);
#line 294 "list-view-row.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	return self ? g_object_ref (self) : NULL;
#line 301 "list-view-row.c"
}


static void _boxes_list_view_row_update_favorite_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_update_favorite ((BoxesListViewRow*) self);
#line 308 "list-view-row.c"
}


static void _boxes_list_view_row_update_thumbnail_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_update_thumbnail ((BoxesListViewRow*) self);
#line 315 "list-view-row.c"
}


static void _boxes_list_view_row_update_info_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_update_info ((BoxesListViewRow*) self);
#line 322 "list-view-row.c"
}


static void _boxes_list_view_row_update_status_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_update_status ((BoxesListViewRow*) self);
#line 329 "list-view-row.c"
}


BoxesListViewRow* boxes_list_view_row_construct (GType object_type, BoxesCollectionItem* item) {
	BoxesListViewRow * self = NULL;
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	BoxesMachine* _tmp2_ = NULL;
	BoxesMachineThumbnailer* _tmp3_ = NULL;
	BoxesMachineThumbnailer* _tmp4_ = NULL;
	BoxesMachineThumbnailer* _tmp5_ = NULL;
	GtkImage* _tmp6_ = NULL;
	BoxesMachineThumbnailer* _tmp7_ = NULL;
	GdkPixbuf* _tmp8_ = NULL;
	GdkPixbuf* _tmp9_ = NULL;
	GtkCheckButton* _tmp10_ = NULL;
	GBinding* _tmp11_ = NULL;
	GBinding* _tmp12_ = NULL;
	BoxesMachine* _tmp13_ = NULL;
	BoxesMachine* _tmp14_ = NULL;
	BoxesBoxConfig* _tmp15_ = NULL;
	BoxesMachine* _tmp16_ = NULL;
	BoxesMachine* _tmp17_ = NULL;
	BoxesMachine* _tmp18_ = NULL;
	BoxesMachine* _tmp19_ = NULL;
	BoxesMachine* _tmp20_ = NULL;
	BoxesMachine* _tmp21_ = NULL;
	BoxesMachine* _tmp22_ = NULL;
	BoxesMachine* _tmp23_ = NULL;
	BoxesMachine* _tmp24_ = NULL;
	BoxesMachine* _tmp25_ = NULL;
	GtkLabel* _tmp26_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_val_if_fail (item != NULL, NULL);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	self = (BoxesListViewRow*) g_object_new (object_type, NULL);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = item;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_set_item (self, _tmp0_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp1_ = boxes_list_view_row_get_machine (self);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp2_ = _tmp1_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp3_ = boxes_machine_thumbnailer_new (_tmp2_, BOXES_LIST_VIEW_ROW_SCREENSHOT_WIDTH, BOXES_LIST_VIEW_ROW_SCREENSHOT_HEIGHT, BOXES_LIST_VIEW_ROW_CENTERED_EMBLEM_SIZE, BOXES_LIST_VIEW_ROW_EMBLEM_SIZE, &BOXES_LIST_VIEW_ROW_FRAME_BORDER_COLOR, &BOXES_LIST_VIEW_ROW_FRAME_BACKGROUND_COLOR);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->thumbnailer);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	self->priv->thumbnailer = _tmp3_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp4_ = self->priv->thumbnailer;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_machine_thumbnailer_set_favorite_emblem_enabled (_tmp4_, FALSE);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp5_ = self->priv->thumbnailer;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_signal_connect_object ((GObject*) _tmp5_, "notify::thumbnail", (GCallback) ___lambda181__g_object_notify, self, 0);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp6_ = self->priv->thumbnail;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp7_ = self->priv->thumbnailer;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp8_ = boxes_machine_thumbnailer_get_thumbnail (_tmp7_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp9_ = _tmp8_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_image_set_from_pixbuf (_tmp6_, _tmp9_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp10_ = self->priv->selection_button;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp11_ = g_object_bind_property_with_closures ((GObject*) self, "selected", (GObject*) _tmp10_, "active", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp12_ = _g_object_ref0 (_tmp11_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->selected_binding);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	self->priv->selected_binding = _tmp12_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp13_ = boxes_list_view_row_get_machine (self);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp14_ = _tmp13_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp15_ = _tmp14_->config;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_signal_connect_object ((GObject*) _tmp15_, "notify::categories", (GCallback) _boxes_list_view_row_update_favorite_g_object_notify, self, 0);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp16_ = boxes_list_view_row_get_machine (self);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp17_ = _tmp16_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_signal_connect_object ((GObject*) _tmp17_, "notify::under-construction", (GCallback) _boxes_list_view_row_update_thumbnail_g_object_notify, self, 0);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp18_ = boxes_list_view_row_get_machine (self);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp19_ = _tmp18_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_signal_connect_object ((GObject*) _tmp19_, "notify::info", (GCallback) _boxes_list_view_row_update_info_g_object_notify, self, 0);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp20_ = boxes_list_view_row_get_machine (self);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp21_ = _tmp20_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_signal_connect_object ((GObject*) _tmp21_, "notify::state", (GCallback) _boxes_list_view_row_update_status_g_object_notify, self, 0);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp22_ = boxes_list_view_row_get_machine (self);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp23_ = _tmp22_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_signal_connect_object ((GObject*) _tmp23_, "notify::status", (GCallback) _boxes_list_view_row_update_status_g_object_notify, self, 0);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_update_thumbnail (self);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_update_favorite (self);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_update_info (self);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_update_status (self);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp24_ = boxes_list_view_row_get_machine (self);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp25_ = _tmp24_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp26_ = self->priv->machine_name;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp25_, "name", (GObject*) _tmp26_, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	return self;
#line 458 "list-view-row.c"
}


BoxesListViewRow* boxes_list_view_row_new (BoxesCollectionItem* item) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	return boxes_list_view_row_construct (BOXES_TYPE_LIST_VIEW_ROW, item);
#line 465 "list-view-row.c"
}


static void boxes_list_view_row_update_thumbnail (BoxesListViewRow* self) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_if_fail (self != NULL);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = boxes_list_view_row_get_machine (self);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp1_ = _tmp0_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp2_ = boxes_machine_get_under_construction (_tmp1_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp3_ = _tmp2_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (_tmp3_) {
#line 486 "list-view-row.c"
		GtkStack* _tmp4_ = NULL;
		GtkSpinner* _tmp5_ = NULL;
		GtkSpinner* _tmp6_ = NULL;
		GtkSpinner* _tmp7_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp4_ = self->priv->stack;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp5_ = self->priv->spinner;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_stack_set_visible_child (_tmp4_, (GtkWidget*) _tmp5_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp6_ = self->priv->spinner;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_spinner_start (_tmp6_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp7_ = self->priv->spinner;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp7_, TRUE);
#line 505 "list-view-row.c"
	} else {
		GtkStack* _tmp8_ = NULL;
		GtkImage* _tmp9_ = NULL;
		GtkSpinner* _tmp10_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp8_ = self->priv->stack;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp9_ = self->priv->thumbnail;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_stack_set_visible_child (_tmp8_, (GtkWidget*) _tmp9_);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp10_ = self->priv->spinner;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_spinner_stop (_tmp10_);
#line 520 "list-view-row.c"
	}
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	for (i = 0; i < stack_length; i++) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
			return TRUE;
#line 533 "list-view-row.c"
		}
	}
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	return FALSE;
#line 538 "list-view-row.c"
}


static void boxes_list_view_row_update_favorite (BoxesListViewRow* self) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	BoxesBoxConfig* _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	gboolean _tmp6_ = FALSE;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_if_fail (self != NULL);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = boxes_list_view_row_get_machine (self);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp1_ = _tmp0_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp2_ = _tmp1_->config;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp3_ = boxes_box_config_get_categories (_tmp2_, &_tmp3__length1);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp4_ = _tmp3_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp4__length1 = _tmp3__length1;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp5_ = _tmp4_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp5__length1 = _tmp4__length1;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp6_ = _vala_string_array_contains (_tmp5_, _tmp4__length1, "favorite");
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (_tmp6_) {
#line 577 "list-view-row.c"
		GtkImage* _tmp7_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp7_ = self->priv->favorite;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_image_set_from_icon_name (_tmp7_, "starred-symbolic", GTK_ICON_SIZE_MENU);
#line 583 "list-view-row.c"
	} else {
		GtkImage* _tmp8_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp8_ = self->priv->favorite;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_image_clear (_tmp8_);
#line 590 "list-view-row.c"
	}
}


static void boxes_list_view_row_update_info (BoxesListViewRow* self) {
	gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	BoxesMachine* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* info = NULL;
	gchar* _tmp18_ = NULL;
	GtkLabel* _tmp19_ = NULL;
	GtkLabel* _tmp20_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_if_fail (self != NULL);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp2_ = boxes_list_view_row_get_machine (self);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp3_ = _tmp2_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp4_ = boxes_machine_get_info (_tmp3_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp5_ = _tmp4_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (_tmp5_ != NULL) {
#line 618 "list-view-row.c"
		BoxesMachine* _tmp6_ = NULL;
		BoxesMachine* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp6_ = boxes_list_view_row_get_machine (self);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp7_ = _tmp6_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp8_ = boxes_machine_get_info (_tmp7_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp9_ = _tmp8_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp1_ = g_strcmp0 (_tmp9_, "") != 0;
#line 633 "list-view-row.c"
	} else {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp1_ = FALSE;
#line 637 "list-view-row.c"
	}
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (_tmp1_) {
#line 641 "list-view-row.c"
		BoxesMachine* _tmp10_ = NULL;
		BoxesMachine* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp10_ = boxes_list_view_row_get_machine (self);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp11_ = _tmp10_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp12_ = boxes_machine_get_info (_tmp11_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp13_ = _tmp12_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp14_ = g_strconcat ("<small>", _tmp13_, NULL);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp15_ = _tmp14_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp16_ = g_strconcat (_tmp15_, "</small>", NULL);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_g_free0 (_tmp0_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp0_ = _tmp16_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_g_free0 (_tmp15_);
#line 669 "list-view-row.c"
	} else {
		gchar* _tmp17_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp17_ = g_strdup ("");
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_g_free0 (_tmp0_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp0_ = _tmp17_;
#line 678 "list-view-row.c"
	}
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp18_ = g_strdup (_tmp0_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	info = _tmp18_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp19_ = self->priv->info_label;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_label_set_label (_tmp19_, info);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp20_ = self->priv->info_label;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp20_, g_strcmp0 (info, "") != 0);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_free0 (info);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_free0 (_tmp0_);
#line 696 "list-view-row.c"
}


static void boxes_list_view_row_update_status (BoxesListViewRow* self) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	BoxesMachine* _tmp10_ = NULL;
	BoxesMachine* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	BoxesMachine* _tmp19_ = NULL;
	BoxesMachine* _tmp20_ = NULL;
	BoxesMachine* _tmp29_ = NULL;
	BoxesMachine* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	gboolean _tmp32_ = FALSE;
	BoxesMachine* _tmp35_ = NULL;
	BoxesMachine* _tmp36_ = NULL;
	gboolean _tmp37_ = FALSE;
	gboolean _tmp38_ = FALSE;
	GtkLabel* _tmp41_ = NULL;
	const gchar* _tmp42_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_if_fail (self != NULL);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = boxes_list_view_row_get_machine (self);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp1_ = _tmp0_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_REMOTE_MACHINE)) {
#line 727 "list-view-row.c"
		BoxesMachine* _tmp2_ = NULL;
		BoxesMachine* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp2_ = boxes_list_view_row_get_machine (self);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp3_ = _tmp2_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp4_ = boxes_machine_get_is_connected (_tmp3_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp5_ = _tmp4_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		boxes_list_view_row_update_status_label_style (self, !_tmp5_);
#line 742 "list-view-row.c"
	} else {
		BoxesMachine* _tmp6_ = NULL;
		BoxesMachine* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
		gboolean _tmp9_ = FALSE;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp6_ = boxes_list_view_row_get_machine (self);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp7_ = _tmp6_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp8_ = boxes_machine_get_is_on (_tmp7_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp9_ = _tmp8_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		boxes_list_view_row_update_status_label_style (self, !_tmp9_);
#line 758 "list-view-row.c"
	}
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp10_ = boxes_list_view_row_get_machine (self);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp11_ = _tmp10_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp12_ = boxes_machine_get_status (_tmp11_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp13_ = _tmp12_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (_tmp13_ != NULL) {
#line 770 "list-view-row.c"
		GtkLabel* _tmp14_ = NULL;
		BoxesMachine* _tmp15_ = NULL;
		BoxesMachine* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp14_ = self->priv->status_label;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp15_ = boxes_list_view_row_get_machine (self);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp16_ = _tmp15_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp17_ = boxes_machine_get_status (_tmp16_);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp18_ = _tmp17_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_label_set_label (_tmp14_, _tmp18_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		return;
#line 790 "list-view-row.c"
	}
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp19_ = boxes_list_view_row_get_machine (self);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp20_ = _tmp19_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, BOXES_TYPE_REMOTE_MACHINE)) {
#line 798 "list-view-row.c"
		const gchar* _tmp21_ = NULL;
		BoxesMachine* _tmp22_ = NULL;
		BoxesMachine* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
		gboolean _tmp25_ = FALSE;
		GtkLabel* _tmp28_ = NULL;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp22_ = boxes_list_view_row_get_machine (self);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp23_ = _tmp22_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp24_ = boxes_machine_get_is_connected (_tmp23_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp25_ = _tmp24_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		if (_tmp25_) {
#line 815 "list-view-row.c"
			const gchar* _tmp26_ = NULL;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
			_tmp26_ = _ ("Connected");
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
			_tmp21_ = _tmp26_;
#line 821 "list-view-row.c"
		} else {
			const gchar* _tmp27_ = NULL;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
			_tmp27_ = _ ("Disconnected");
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
			_tmp21_ = _tmp27_;
#line 828 "list-view-row.c"
		}
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp28_ = self->priv->status_label;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_label_set_label (_tmp28_, _tmp21_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		return;
#line 836 "list-view-row.c"
	}
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp29_ = boxes_list_view_row_get_machine (self);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp30_ = _tmp29_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp31_ = boxes_machine_get_is_running (_tmp30_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp32_ = _tmp31_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (_tmp32_) {
#line 848 "list-view-row.c"
		GtkLabel* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp33_ = self->priv->status_label;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp34_ = _ ("Running");
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_label_set_label (_tmp33_, _tmp34_);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		return;
#line 859 "list-view-row.c"
	}
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp35_ = boxes_list_view_row_get_machine (self);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp36_ = _tmp35_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp37_ = boxes_machine_get_is_on (_tmp36_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp38_ = _tmp37_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (_tmp38_) {
#line 871 "list-view-row.c"
		GtkLabel* _tmp39_ = NULL;
		const gchar* _tmp40_ = NULL;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp39_ = self->priv->status_label;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp40_ = _ ("Paused");
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_label_set_label (_tmp39_, _tmp40_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		return;
#line 882 "list-view-row.c"
	}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp41_ = self->priv->status_label;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp42_ = _ ("Powered Off");
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_label_set_label (_tmp41_, _tmp42_);
#line 890 "list-view-row.c"
}


static void boxes_list_view_row_update_status_label_style (BoxesListViewRow* self, gboolean dim) {
	gboolean _tmp0_ = FALSE;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_if_fail (self != NULL);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = dim;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (_tmp0_) {
#line 902 "list-view-row.c"
		GtkLabel* _tmp1_ = NULL;
		GtkStyleContext* _tmp2_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp1_ = self->priv->status_label;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) _tmp1_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_style_context_add_class (_tmp2_, "dim-label");
#line 911 "list-view-row.c"
	} else {
		GtkLabel* _tmp3_ = NULL;
		GtkStyleContext* _tmp4_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp3_ = self->priv->status_label;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		gtk_style_context_remove_class (_tmp4_, "dim-label");
#line 921 "list-view-row.c"
	}
}


gboolean boxes_list_view_row_get_selection_mode (BoxesListViewRow* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = self->_selection_mode;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	result = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	return result;
#line 937 "list-view-row.c"
}


void boxes_list_view_row_set_selection_mode (BoxesListViewRow* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	GtkCheckButton* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	self->_selection_mode = _tmp0_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp1_ = self->priv->selection_button;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp2_ = self->_selection_mode;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp1_, _tmp2_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp3_ = self->_selection_mode;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (!_tmp3_) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		boxes_list_view_row_set_selected (self, FALSE);
#line 964 "list-view-row.c"
	}
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_object_notify ((GObject *) self, "selection-mode");
#line 968 "list-view-row.c"
}


gboolean boxes_list_view_row_get_selected (BoxesListViewRow* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = self->_selected;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	result = _tmp0_;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	return result;
#line 983 "list-view-row.c"
}


void boxes_list_view_row_set_selected (BoxesListViewRow* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_if_fail (self != NULL);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp1_ = boxes_list_view_row_get_selection_mode (self);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp2_ = _tmp1_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	if (_tmp2_) {
#line 999 "list-view-row.c"
		gboolean _tmp3_ = FALSE;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp3_ = value;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp0_ = _tmp3_;
#line 1005 "list-view-row.c"
	} else {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		_tmp0_ = FALSE;
#line 1009 "list-view-row.c"
	}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	self->_selected = _tmp0_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_object_notify ((GObject *) self, "selected");
#line 1015 "list-view-row.c"
}


BoxesCollectionItem* boxes_list_view_row_get_item (BoxesListViewRow* self) {
	BoxesCollectionItem* result;
	BoxesCollectionItem* _tmp0_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = self->priv->_item;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	result = _tmp0_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	return result;
#line 1030 "list-view-row.c"
}


static void boxes_list_view_row_set_item (BoxesListViewRow* self, BoxesCollectionItem* value) {
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_if_fail (self != NULL);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = value;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->_item);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	self->priv->_item = _tmp1_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_object_notify ((GObject *) self, "item");
#line 1049 "list-view-row.c"
}


static BoxesMachine* boxes_list_view_row_get_machine (BoxesListViewRow* self) {
	BoxesMachine* result;
	BoxesCollectionItem* _tmp0_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_tmp0_ = self->priv->_item;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp0_) : NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	return result;
#line 1064 "list-view-row.c"
}


static void boxes_list_view_row_class_init (BoxesListViewRowClass * klass) {
	gint BoxesListViewRow_private_offset;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	boxes_list_view_row_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_type_class_add_private (klass, sizeof (BoxesListViewRowPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_list_view_row_get_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_list_view_row_set_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_list_view_row_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIST_VIEW_ROW_SELECTION_MODE, g_param_spec_boolean ("selection-mode", "selection-mode", "selection-mode", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIST_VIEW_ROW_SELECTED, g_param_spec_boolean ("selected", "selected", "selected", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIST_VIEW_ROW_ITEM, g_param_spec_object ("item", "item", "item", BOXES_TYPE_COLLECTION_ITEM, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	BoxesListViewRow_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/list-view-row.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "selection_button", FALSE, BoxesListViewRow_private_offset + G_STRUCT_OFFSET (BoxesListViewRowPrivate, selection_button));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "stack", FALSE, BoxesListViewRow_private_offset + G_STRUCT_OFFSET (BoxesListViewRowPrivate, stack));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "thumbnail", FALSE, BoxesListViewRow_private_offset + G_STRUCT_OFFSET (BoxesListViewRowPrivate, thumbnail));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "spinner", FALSE, BoxesListViewRow_private_offset + G_STRUCT_OFFSET (BoxesListViewRowPrivate, spinner));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "favorite", FALSE, BoxesListViewRow_private_offset + G_STRUCT_OFFSET (BoxesListViewRowPrivate, favorite));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "machine_name", FALSE, BoxesListViewRow_private_offset + G_STRUCT_OFFSET (BoxesListViewRowPrivate, machine_name));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "info_label", FALSE, BoxesListViewRow_private_offset + G_STRUCT_OFFSET (BoxesListViewRowPrivate, info_label));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "status_label", FALSE, BoxesListViewRow_private_offset + G_STRUCT_OFFSET (BoxesListViewRowPrivate, status_label));
#line 1106 "list-view-row.c"
}


static void boxes_list_view_row_instance_init (BoxesListViewRow * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	self->priv = BOXES_LIST_VIEW_ROW_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1115 "list-view-row.c"
}


static void boxes_list_view_row_finalize (GObject* obj) {
	BoxesListViewRow * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIST_VIEW_ROW, BoxesListViewRow);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->_item);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->selection_button);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->stack);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->thumbnail);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->spinner);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->favorite);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->machine_name);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->info_label);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->status_label);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->thumbnailer);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	_g_object_unref0 (self->priv->selected_binding);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	G_OBJECT_CLASS (boxes_list_view_row_parent_class)->finalize (obj);
#line 1147 "list-view-row.c"
}


GType boxes_list_view_row_get_type (void) {
	static volatile gsize boxes_list_view_row_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_list_view_row_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesListViewRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_list_view_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesListViewRow), 0, (GInstanceInitFunc) boxes_list_view_row_instance_init, NULL };
		GType boxes_list_view_row_type_id;
		boxes_list_view_row_type_id = g_type_register_static (gtk_box_get_type (), "BoxesListViewRow", &g_define_type_info, 0);
		g_once_init_leave (&boxes_list_view_row_type_id__volatile, boxes_list_view_row_type_id);
	}
	return boxes_list_view_row_type_id__volatile;
}


static void _vala_boxes_list_view_row_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesListViewRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_LIST_VIEW_ROW, BoxesListViewRow);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		case BOXES_LIST_VIEW_ROW_SELECTION_MODE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		g_value_set_boolean (value, boxes_list_view_row_get_selection_mode (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		case BOXES_LIST_VIEW_ROW_SELECTED:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		g_value_set_boolean (value, boxes_list_view_row_get_selected (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		case BOXES_LIST_VIEW_ROW_ITEM:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		g_value_set_object (value, boxes_list_view_row_get_item (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		break;
#line 1186 "list-view-row.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		break;
#line 1192 "list-view-row.c"
	}
}


static void _vala_boxes_list_view_row_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesListViewRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_LIST_VIEW_ROW, BoxesListViewRow);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		case BOXES_LIST_VIEW_ROW_SELECTION_MODE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		boxes_list_view_row_set_selection_mode (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		case BOXES_LIST_VIEW_ROW_SELECTED:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		boxes_list_view_row_set_selected (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		case BOXES_LIST_VIEW_ROW_ITEM:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		boxes_list_view_row_set_item (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		break;
#line 1220 "list-view-row.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/list-view-row.vala"
		break;
#line 1226 "list-view-row.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 1234 "list-view-row.c"
		int i;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 1242 "list-view-row.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 1254 "list-view-row.c"
}



