/* actions-popover.c generated by valac 0.32.0.73-ab1d1, the Vala compiler
 * generated from actions-popover.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <atk/atk.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>


#define BOXES_TYPE_ACTIONS_POPOVER (boxes_actions_popover_get_type ())
#define BOXES_ACTIONS_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopover))
#define BOXES_ACTIONS_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverClass))
#define BOXES_IS_ACTIONS_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ACTIONS_POPOVER))
#define BOXES_IS_ACTIONS_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ACTIONS_POPOVER))
#define BOXES_ACTIONS_POPOVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverClass))

typedef struct _BoxesActionsPopover BoxesActionsPopover;
typedef struct _BoxesActionsPopoverClass BoxesActionsPopoverClass;
typedef struct _BoxesActionsPopoverPrivate BoxesActionsPopoverPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _Block12Data Block12Data;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

struct _BoxesActionsPopover {
	GtkPopover parent_instance;
	BoxesActionsPopoverPrivate * priv;
};

struct _BoxesActionsPopoverClass {
	GtkPopoverClass parent_class;
};

struct _BoxesActionsPopoverPrivate {
	BoxesAppWindow* window;
	GSimpleActionGroup* action_group;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*clone) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*clone_finish) (BoxesMachine* self, GAsyncResult* _res_);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_can_restart) (BoxesMachine* self);
	gboolean (*get_can_clone) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

struct _Block12Data {
	int _ref_count_;
	BoxesActionsPopover* self;
	BoxesMachine* machine;
};

typedef void (*BoxesAppUndoNotifyCallback) (void* user_data);

static gpointer boxes_actions_popover_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_actions_popover_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_ACTIONS_POPOVER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverPrivate))
enum  {
	BOXES_ACTIONS_POPOVER_DUMMY_PROPERTY
};
static void boxes_actions_popover_open_in_new_win_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_open_in_new_win_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_favorite_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_favorite_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_pause_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_pause_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_force_shutdown_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_force_shutdown_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_delete_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_delete_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_clone_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_clone_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_properties_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_properties_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_actions_popover_restart_activated (BoxesActionsPopover* self);
static void _boxes_actions_popover_restart_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
BoxesActionsPopover* boxes_actions_popover_new (BoxesAppWindow* window);
BoxesActionsPopover* boxes_actions_popover_construct (GType object_type, BoxesAppWindow* window);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
void boxes_actions_popover_update_for_item (BoxesActionsPopover* self, BoxesCollectionItem* item);
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
gboolean boxes_machine_get_is_running (BoxesMachine* self);
gboolean boxes_machine_get_can_save (BoxesMachine* self);
gboolean boxes_machine_get_can_clone (BoxesMachine* self);
gboolean boxes_machine_get_can_delete (BoxesMachine* self);
gboolean boxes_machine_get_can_restart (BoxesMachine* self);
void boxes_app_window_set_current_item (BoxesAppWindow* self, BoxesCollectionItem* value);
GType boxes_app_get_type (void) G_GNUC_CONST;
void boxes_app_open_in_new_window (BoxesApp* self, BoxesMachine* machine);
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void block12_data_unref (void * _userdata_);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void __lambda198_ (Block12Data* _data12_, GObject* obj, GAsyncResult* _result_);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void ___lambda198__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self);
void boxes_machine_restart (BoxesMachine* self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
void boxes_app_delete_machines_undoable (BoxesApp* self, GList* items, const gchar* message, BoxesAppUndoNotifyCallback undo_notify_callback, void* undo_notify_callback_target, GDestroyNotify undo_notify_callback_target_destroy_notify);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
void boxes_machine_clone (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_clone_finish (BoxesMachine* self, GAsyncResult* _res_);
void boxes_app_window_show_properties (BoxesAppWindow* self);
static void boxes_actions_popover_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GActionEntry BOXES_ACTIONS_POPOVER_action_entries[8] = {{"open-in-new-win", _boxes_actions_popover_open_in_new_win_activated_gsimple_action_activate_callback}, {"favorite", _boxes_actions_popover_favorite_activated_gsimple_action_activate_callback}, {"pause", _boxes_actions_popover_pause_activated_gsimple_action_activate_callback}, {"force_shutdown", _boxes_actions_popover_force_shutdown_activated_gsimple_action_activate_callback}, {"delete", _boxes_actions_popover_delete_activated_gsimple_action_activate_callback}, {"clone", _boxes_actions_popover_clone_activated_gsimple_action_activate_callback}, {"properties", _boxes_actions_popover_properties_activated_gsimple_action_activate_callback}, {"restart", _boxes_actions_popover_restart_activated_gsimple_action_activate_callback}};

static void _boxes_actions_popover_open_in_new_win_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_open_in_new_win_activated ((BoxesActionsPopover*) self);
#line 306 "actions-popover.c"
}


static void _boxes_actions_popover_favorite_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_favorite_activated ((BoxesActionsPopover*) self);
#line 313 "actions-popover.c"
}


static void _boxes_actions_popover_pause_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_pause_activated ((BoxesActionsPopover*) self);
#line 320 "actions-popover.c"
}


static void _boxes_actions_popover_force_shutdown_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_force_shutdown_activated ((BoxesActionsPopover*) self);
#line 327 "actions-popover.c"
}


static void _boxes_actions_popover_delete_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_delete_activated ((BoxesActionsPopover*) self);
#line 334 "actions-popover.c"
}


static void _boxes_actions_popover_clone_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_clone_activated ((BoxesActionsPopover*) self);
#line 341 "actions-popover.c"
}


static void _boxes_actions_popover_properties_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_properties_activated ((BoxesActionsPopover*) self);
#line 348 "actions-popover.c"
}


static void _boxes_actions_popover_restart_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_restart_activated ((BoxesActionsPopover*) self);
#line 355 "actions-popover.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	return self ? g_object_ref (self) : NULL;
#line 362 "actions-popover.c"
}


BoxesActionsPopover* boxes_actions_popover_construct (GType object_type, BoxesAppWindow* window) {
	BoxesActionsPopover * self = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	GSimpleActionGroup* _tmp2_ = NULL;
	GSimpleActionGroup* _tmp3_ = NULL;
	GSimpleActionGroup* _tmp4_ = NULL;
	AtkObject* a11y = NULL;
	AtkObject* _tmp5_ = NULL;
	AtkObject* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_val_if_fail (window != NULL, NULL);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	self = (BoxesActionsPopover*) g_object_new (object_type, NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = window;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (self->priv->window);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	self->priv->window = _tmp1_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = g_simple_action_group_new ();
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (self->priv->action_group);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	self->priv->action_group = _tmp2_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = self->priv->action_group;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_action_map_add_action_entries ((GActionMap*) _tmp3_, BOXES_ACTIONS_POPOVER_action_entries, G_N_ELEMENTS (BOXES_ACTIONS_POPOVER_action_entries), self);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp4_ = self->priv->action_group;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	gtk_widget_insert_action_group ((GtkWidget*) self, "box", (GActionGroup*) _tmp4_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp5_ = gtk_widget_get_accessible ((GtkWidget*) self);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	a11y = _tmp6_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	a11y->role = ATK_ROLE_POPUP_MENU;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp7_ = _ ("Box actions");
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	a11y->name = _tmp7_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (a11y);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	return self;
#line 419 "actions-popover.c"
}


BoxesActionsPopover* boxes_actions_popover_new (BoxesAppWindow* window) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	return boxes_actions_popover_construct (BOXES_TYPE_ACTIONS_POPOVER, window);
#line 426 "actions-popover.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	for (i = 0; i < stack_length; i++) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
			return TRUE;
#line 438 "actions-popover.c"
		}
	}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	return FALSE;
#line 443 "actions-popover.c"
}


void boxes_actions_popover_update_for_item (BoxesActionsPopover* self, BoxesCollectionItem* item) {
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesMachine* machine = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesMachine* _tmp2_ = NULL;
	GMenu* menu = NULL;
	GMenu* _tmp3_ = NULL;
	GMenu* section = NULL;
	GMenu* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	BoxesMachine* _tmp6_ = NULL;
	gboolean importing = FALSE;
	BoxesAppWindow* _tmp10_ = NULL;
	BoxesUIState _tmp11_ = 0;
	BoxesUIState _tmp12_ = 0;
	BoxesMachine* _tmp20_ = NULL;
	BoxesBoxConfig* _tmp21_ = NULL;
	gchar** _tmp22_ = NULL;
	gint _tmp22__length1 = 0;
	gchar** _tmp23_ = NULL;
	gint _tmp23__length1 = 0;
	gchar** _tmp24_ = NULL;
	gint _tmp24__length1 = 0;
	gboolean _tmp25_ = FALSE;
	GMenu* _tmp30_ = NULL;
	GMenu* _tmp31_ = NULL;
	GMenu* _tmp32_ = NULL;
	BoxesMachine* _tmp33_ = NULL;
	BoxesAppWindow* _tmp43_ = NULL;
	BoxesUIState _tmp44_ = 0;
	BoxesUIState _tmp45_ = 0;
	GMenu* _tmp82_ = NULL;
	GMenu* _tmp83_ = NULL;
	GMenu* _tmp84_ = NULL;
	GMenu* _tmp85_ = NULL;
	const gchar* _tmp86_ = NULL;
	GMenu* _tmp87_ = NULL;
	GMenu* _tmp88_ = NULL;
	GSimpleAction* action = NULL;
	GSimpleActionGroup* _tmp89_ = NULL;
	GAction* _tmp90_ = NULL;
	GSimpleAction* _tmp91_ = NULL;
	gboolean _tmp92_ = FALSE;
	GMenu* _tmp93_ = NULL;
	BoxesAppWindow* _tmp94_ = NULL;
	BoxesCollectionItem* _tmp95_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (item != NULL);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = item;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_MACHINE));
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = item;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp1_) : NULL);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	machine = _tmp2_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = g_menu_new ();
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	menu = _tmp3_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp4_ = g_menu_new ();
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	section = _tmp4_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp6_ = machine;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 519 "actions-popover.c"
		BoxesMachine* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
		gboolean _tmp9_ = FALSE;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp7_ = machine;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp8_ = boxes_libvirt_machine_get_importing (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp7_) : NULL);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp9_ = _tmp8_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp5_ = _tmp9_;
#line 531 "actions-popover.c"
	} else {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp5_ = FALSE;
#line 535 "actions-popover.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	importing = _tmp5_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp10_ = self->priv->window;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp11_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp10_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp12_ = _tmp11_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	if (_tmp12_ != BOXES_UI_STATE_DISPLAY) {
#line 547 "actions-popover.c"
		GMenu* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		GSimpleAction* action = NULL;
		GSimpleActionGroup* _tmp15_ = NULL;
		GAction* _tmp16_ = NULL;
		GSimpleAction* _tmp17_ = NULL;
		GSimpleAction* _tmp18_ = NULL;
		gboolean _tmp19_ = FALSE;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp13_ = section;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp14_ = _ ("Open in New Window");
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp13_, _tmp14_, "box.open-in-new-win");
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp15_ = self->priv->action_group;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp16_ = g_action_map_lookup_action ((GActionMap*) _tmp15_, "open-in-new-win");
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp16_) : NULL);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		action = _tmp17_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp18_ = action;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp19_ = importing;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp18_, !_tmp19_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 578 "actions-popover.c"
	}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp20_ = machine;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp21_ = _tmp20_->config;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp22_ = boxes_box_config_get_categories (_tmp21_, &_tmp22__length1);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp23_ = _tmp22_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp23__length1 = _tmp22__length1;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp24_ = _tmp23_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp24__length1 = _tmp23__length1;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp25_ = _vala_string_array_contains (_tmp24_, _tmp23__length1, "favorite");
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp24_ = (_vala_array_free (_tmp24_, _tmp24__length1, (GDestroyNotify) g_free), NULL);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	if (_tmp25_) {
#line 600 "actions-popover.c"
		GMenu* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp26_ = section;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp27_ = _ ("Remove from Favorites");
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp26_, _tmp27_, "box.favorite");
#line 609 "actions-popover.c"
	} else {
		GMenu* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp28_ = section;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp29_ = _ ("Add to Favorites");
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp28_, _tmp29_, "box.favorite");
#line 619 "actions-popover.c"
	}
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp30_ = menu;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp31_ = section;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_menu_append_section (_tmp30_, NULL, (GMenuModel*) _tmp31_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp32_ = g_menu_new ();
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (section);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	section = _tmp32_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp33_ = machine;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp33_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 637 "actions-popover.c"
		GMenu* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		GSimpleAction* action = NULL;
		GSimpleActionGroup* _tmp36_ = NULL;
		GAction* _tmp37_ = NULL;
		GSimpleAction* _tmp38_ = NULL;
		GSimpleAction* _tmp39_ = NULL;
		BoxesMachine* _tmp40_ = NULL;
		gboolean _tmp41_ = FALSE;
		gboolean _tmp42_ = FALSE;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp34_ = section;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp35_ = _ ("Force Shutdown");
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp34_, _tmp35_, "box.force_shutdown");
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp36_ = self->priv->action_group;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp37_ = g_action_map_lookup_action ((GActionMap*) _tmp36_, "force_shutdown");
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp38_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp37_) : NULL);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		action = _tmp38_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp39_ = action;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp40_ = machine;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp41_ = boxes_machine_get_is_running (_tmp40_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp42_ = _tmp41_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp39_, _tmp42_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 674 "actions-popover.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp43_ = self->priv->window;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp44_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp43_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp45_ = _tmp44_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	if (_tmp45_ != BOXES_UI_STATE_DISPLAY) {
#line 684 "actions-popover.c"
		GMenu* _tmp46_ = NULL;
		const gchar* _tmp47_ = NULL;
		GSimpleAction* action = NULL;
		GSimpleActionGroup* _tmp48_ = NULL;
		GAction* _tmp49_ = NULL;
		GSimpleAction* _tmp50_ = NULL;
		GSimpleAction* _tmp51_ = NULL;
		BoxesMachine* _tmp52_ = NULL;
		gboolean _tmp53_ = FALSE;
		gboolean _tmp54_ = FALSE;
		GMenu* _tmp55_ = NULL;
		const gchar* _tmp56_ = NULL;
		GSimpleActionGroup* _tmp57_ = NULL;
		GAction* _tmp58_ = NULL;
		GSimpleAction* _tmp59_ = NULL;
		GSimpleAction* _tmp60_ = NULL;
		BoxesMachine* _tmp61_ = NULL;
		gboolean _tmp62_ = FALSE;
		gboolean _tmp63_ = FALSE;
		GMenu* _tmp64_ = NULL;
		const gchar* _tmp65_ = NULL;
		GSimpleActionGroup* _tmp66_ = NULL;
		GAction* _tmp67_ = NULL;
		GSimpleAction* _tmp68_ = NULL;
		GSimpleAction* _tmp69_ = NULL;
		BoxesMachine* _tmp70_ = NULL;
		gboolean _tmp71_ = FALSE;
		gboolean _tmp72_ = FALSE;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp46_ = section;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp47_ = _ ("Pause");
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp46_, _tmp47_, "box.pause");
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp48_ = self->priv->action_group;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp49_ = g_action_map_lookup_action ((GActionMap*) _tmp48_, "pause");
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp50_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp49_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp49_) : NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		action = _tmp50_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp51_ = action;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp52_ = machine;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp53_ = boxes_machine_get_can_save (_tmp52_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp54_ = _tmp53_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp51_, _tmp54_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp55_ = section;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp56_ = _ ("Clone");
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp55_, _tmp56_, "box.clone");
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp57_ = self->priv->action_group;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp58_ = g_action_map_lookup_action ((GActionMap*) _tmp57_, "clone");
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp59_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp58_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp58_) : NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		action = _tmp59_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp60_ = action;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp61_ = machine;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp62_ = boxes_machine_get_can_clone (_tmp61_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp63_ = _tmp62_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp60_, _tmp63_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp64_ = section;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp65_ = _ ("Delete");
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp64_, _tmp65_, "box.delete");
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp66_ = self->priv->action_group;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp67_ = g_action_map_lookup_action ((GActionMap*) _tmp66_, "delete");
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp68_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp67_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp67_) : NULL);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		action = _tmp68_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp69_ = action;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp70_ = machine;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp71_ = boxes_machine_get_can_delete (_tmp70_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp72_ = _tmp71_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp69_, _tmp72_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 791 "actions-popover.c"
	} else {
		GMenu* _tmp73_ = NULL;
		const gchar* _tmp74_ = NULL;
		GSimpleAction* action = NULL;
		GSimpleActionGroup* _tmp75_ = NULL;
		GAction* _tmp76_ = NULL;
		GSimpleAction* _tmp77_ = NULL;
		GSimpleAction* _tmp78_ = NULL;
		BoxesMachine* _tmp79_ = NULL;
		gboolean _tmp80_ = FALSE;
		gboolean _tmp81_ = FALSE;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp73_ = section;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp74_ = _ ("Restart");
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_menu_append (_tmp73_, _tmp74_, "box.restart");
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp75_ = self->priv->action_group;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp76_ = g_action_map_lookup_action ((GActionMap*) _tmp75_, "restart");
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp77_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp76_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp76_) : NULL);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		action = _tmp77_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp78_ = action;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp79_ = machine;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp80_ = boxes_machine_get_can_restart (_tmp79_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp81_ = _tmp80_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_simple_action_set_enabled (_tmp78_, _tmp81_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (action);
#line 829 "actions-popover.c"
	}
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp82_ = menu;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp83_ = section;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_menu_append_section (_tmp82_, NULL, (GMenuModel*) _tmp83_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp84_ = g_menu_new ();
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (section);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	section = _tmp84_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp85_ = section;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp86_ = _ ("Properties");
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_menu_append (_tmp85_, _tmp86_, "box.properties");
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp87_ = menu;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp88_ = section;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_menu_append_section (_tmp87_, NULL, (GMenuModel*) _tmp88_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp89_ = self->priv->action_group;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp90_ = g_action_map_lookup_action ((GActionMap*) _tmp89_, "properties");
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp91_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp90_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp90_) : NULL);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	action = _tmp91_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp92_ = importing;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_simple_action_set_enabled (action, !_tmp92_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp93_ = menu;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	gtk_popover_bind_model ((GtkPopover*) self, (GMenuModel*) _tmp93_, NULL);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp94_ = self->priv->window;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp95_ = item;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_app_window_set_current_item (_tmp94_, _tmp95_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (action);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (section);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (menu);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (machine);
#line 885 "actions-popover.c"
}


static void boxes_actions_popover_open_in_new_win_activated (BoxesActionsPopover* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesCollectionItem* _tmp3_ = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = boxes_app_app;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = self->priv->window;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = boxes_app_window_get_current_item (_tmp1_);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _tmp2_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_app_open_in_new_window (_tmp0_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp3_) : NULL);
#line 906 "actions-popover.c"
}


static void boxes_actions_popover_favorite_activated (BoxesActionsPopover* self) {
	BoxesMachine* machine = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
	gboolean enabled = FALSE;
	BoxesBoxConfig* _tmp4_ = NULL;
	gchar** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	gchar** _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
	gchar** _tmp7_ = NULL;
	gint _tmp7__length1 = 0;
	gboolean _tmp8_ = FALSE;
	BoxesBoxConfig* _tmp9_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	machine = _tmp3_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp4_ = machine->config;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp5_ = boxes_box_config_get_categories (_tmp4_, &_tmp5__length1);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp6_ = _tmp5_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp6__length1 = _tmp5__length1;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp7_ = _tmp6_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp7__length1 = _tmp6__length1;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp8_ = !_vala_string_array_contains (_tmp7_, _tmp6__length1, "favorite");
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp7_ = (_vala_array_free (_tmp7_, _tmp7__length1, (GDestroyNotify) g_free), NULL);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	enabled = _tmp8_;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp9_ = machine->config;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_box_config_set_category (_tmp9_, "favorite", enabled);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (machine);
#line 962 "actions-popover.c"
}


static Block12Data* block12_data_ref (Block12Data* _data12_) {
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_atomic_int_inc (&_data12_->_ref_count_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	return _data12_;
#line 971 "actions-popover.c"
}


static void block12_data_unref (void * _userdata_) {
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
#line 980 "actions-popover.c"
		BoxesActionsPopover* self;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		self = _data12_->self;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (_data12_->machine);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (self);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_slice_free (Block12Data, _data12_);
#line 990 "actions-popover.c"
	}
}


static void __lambda198_ (Block12Data* _data12_, GObject* obj, GAsyncResult* _result_) {
	BoxesActionsPopover* self;
	GError * _inner_error_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	self = _data12_->self;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (_result_ != NULL);
#line 1002 "actions-popover.c"
	{
		GAsyncResult* _tmp0_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp0_ = _result_;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		boxes_machine_save_finish (_data12_->machine, _tmp0_, &_inner_error_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1011 "actions-popover.c"
			goto __catch7_g_error;
		}
	}
	goto __finally7;
	__catch7_g_error:
	{
		GError* e = NULL;
		BoxesAppWindow* _tmp1_ = NULL;
		BoxesNotificationbar* _tmp2_ = NULL;
		BoxesNotificationbar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		GdNotification* _tmp9_ = NULL;
		GdNotification* _tmp10_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		e = _inner_error_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_inner_error_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp1_ = self->priv->window;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp2_ = boxes_app_window_get_notificationbar (_tmp1_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp3_ = _tmp2_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp4_ = _ ("Pausing '%s' failed");
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp5_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data12_->machine);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp6_ = _tmp5_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp7_ = g_strdup_printf (_tmp4_, _tmp6_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp8_ = _tmp7_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp9_ = boxes_notificationbar_display_error (_tmp3_, _tmp8_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_tmp10_ = _tmp9_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_object_unref0 (_tmp10_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_free0 (_tmp8_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		_g_error_free0 (e);
#line 1059 "actions-popover.c"
	}
	__finally7:
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		g_clear_error (&_inner_error_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
		return;
#line 1070 "actions-popover.c"
	}
}


static void ___lambda198__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	__lambda198_ (self, source_object, res);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	block12_data_unref (self);
#line 1080 "actions-popover.c"
}


static void boxes_actions_popover_pause_activated (BoxesActionsPopover* self) {
	Block12Data* _data12_;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_data12_ = g_slice_new0 (Block12Data);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_data12_->_ref_count_ = 1;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_data12_->self = g_object_ref (self);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_data12_->machine = _tmp3_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_machine_save (_data12_->machine, ___lambda198__gasync_ready_callback, block12_data_ref (_data12_));
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	block12_data_unref (_data12_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_data12_ = NULL;
#line 1114 "actions-popover.c"
}


static void boxes_actions_popover_force_shutdown_activated (BoxesActionsPopover* self) {
	BoxesLibvirtMachine* machine = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp2_) : NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	machine = _tmp3_;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_libvirt_machine_force_shutdown (machine);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (machine);
#line 1140 "actions-popover.c"
}


static void boxes_actions_popover_restart_activated (BoxesActionsPopover* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_machine_restart (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 1158 "actions-popover.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1165 "actions-popover.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_list_free (self);
#line 1174 "actions-popover.c"
}


static void boxes_actions_popover_delete_activated (BoxesActionsPopover* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	GList* items = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesCollectionItem* _tmp3_ = NULL;
	BoxesCollectionItem* _tmp4_ = NULL;
	BoxesApp* _tmp5_ = NULL;
	GList* _tmp6_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	items = NULL;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = self->priv->window;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = boxes_app_window_get_current_item (_tmp1_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp3_ = _tmp2_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	items = g_list_append (items, _tmp4_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp5_ = boxes_app_app;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp6_ = items;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	items = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_app_delete_machines_undoable (_tmp5_, _tmp6_, NULL, NULL, NULL, NULL);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	__g_list_free__g_object_unref0_0 (items);
#line 1215 "actions-popover.c"
}


static void boxes_actions_popover_clone_activated (BoxesActionsPopover* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp2_ = _tmp1_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_machine_clone (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL, NULL, NULL);
#line 1233 "actions-popover.c"
}


static void boxes_actions_popover_properties_activated (BoxesActionsPopover* self) {
	BoxesAppWindow* _tmp0_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_return_if_fail (self != NULL);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_tmp0_ = self->priv->window;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_app_window_show_properties (_tmp0_);
#line 1245 "actions-popover.c"
}


static void boxes_actions_popover_class_init (BoxesActionsPopoverClass * klass) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	boxes_actions_popover_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	g_type_class_add_private (klass, sizeof (BoxesActionsPopoverPrivate));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_actions_popover_finalize;
#line 1256 "actions-popover.c"
}


static void boxes_actions_popover_instance_init (BoxesActionsPopover * self) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	self->priv = BOXES_ACTIONS_POPOVER_GET_PRIVATE (self);
#line 1263 "actions-popover.c"
}


static void boxes_actions_popover_finalize (GObject* obj) {
	BoxesActionsPopover * self;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopover);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (self->priv->window);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	_g_object_unref0 (self->priv->action_group);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/actions-popover.vala"
	G_OBJECT_CLASS (boxes_actions_popover_parent_class)->finalize (obj);
#line 1277 "actions-popover.c"
}


GType boxes_actions_popover_get_type (void) {
	static volatile gsize boxes_actions_popover_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_actions_popover_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesActionsPopoverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_actions_popover_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesActionsPopover), 0, (GInstanceInitFunc) boxes_actions_popover_instance_init, NULL };
		GType boxes_actions_popover_type_id;
		boxes_actions_popover_type_id = g_type_register_static (gtk_popover_get_type (), "BoxesActionsPopover", &g_define_type_info, 0);
		g_once_init_leave (&boxes_actions_popover_type_id__volatile, boxes_actions_popover_type_id);
	}
	return boxes_actions_popover_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



