/* properties-toolbar.c generated by valac 0.32.0.73-ab1d1, the Vala compiler
 * generated from properties-toolbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>


#define BOXES_TYPE_PROPERTIES_TOOLBAR (boxes_properties_toolbar_get_type ())
#define BOXES_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar))
#define BOXES_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))
#define BOXES_IS_PROPERTIES_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_IS_PROPERTIES_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_TOOLBAR))
#define BOXES_PROPERTIES_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarClass))

typedef struct _BoxesPropertiesToolbar BoxesPropertiesToolbar;
typedef struct _BoxesPropertiesToolbarClass BoxesPropertiesToolbarClass;
typedef struct _BoxesPropertiesToolbarPrivate BoxesPropertiesToolbarPrivate;

#define BOXES_TYPE_PROPS_WINDOW_PAGE (boxes_props_window_page_get_type ())

#define BOXES_TYPE_EDITABLE_ENTRY (boxes_editable_entry_get_type ())
#define BOXES_EDITABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntry))
#define BOXES_EDITABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryClass))
#define BOXES_IS_EDITABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EDITABLE_ENTRY))
#define BOXES_IS_EDITABLE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EDITABLE_ENTRY))
#define BOXES_EDITABLE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EDITABLE_ENTRY, BoxesEditableEntryClass))

typedef struct _BoxesEditableEntry BoxesEditableEntry;
typedef struct _BoxesEditableEntryClass BoxesEditableEntryClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_PROPERTIES_WINDOW (boxes_properties_window_get_type ())
#define BOXES_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindow))
#define BOXES_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))
#define BOXES_IS_PROPERTIES_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_IS_PROPERTIES_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES_WINDOW))
#define BOXES_PROPERTIES_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES_WINDOW, BoxesPropertiesWindowClass))

typedef struct _BoxesPropertiesWindow BoxesPropertiesWindow;
typedef struct _BoxesPropertiesWindowClass BoxesPropertiesWindowClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block74Data Block74Data;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesPropertiesWindowPrivate BoxesPropertiesWindowPrivate;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_TROUBLESHOOT_LOG (boxes_troubleshoot_log_get_type ())
#define BOXES_TROUBLESHOOT_LOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLog))
#define BOXES_TROUBLESHOOT_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLogClass))
#define BOXES_IS_TROUBLESHOOT_LOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TROUBLESHOOT_LOG))
#define BOXES_IS_TROUBLESHOOT_LOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TROUBLESHOOT_LOG))
#define BOXES_TROUBLESHOOT_LOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TROUBLESHOOT_LOG, BoxesTroubleshootLogClass))

typedef struct _BoxesTroubleshootLog BoxesTroubleshootLog;
typedef struct _BoxesTroubleshootLogClass BoxesTroubleshootLogClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _BoxesPropertiesToolbar {
	GtkStack parent_instance;
	BoxesPropertiesToolbarPrivate * priv;
	GtkHeaderBar* main;
	GtkButton* troubleshooting_back_button;
};

struct _BoxesPropertiesToolbarClass {
	GtkStackClass parent_class;
};

typedef enum  {
	BOXES_PROPS_WINDOW_PAGE_MAIN,
	BOXES_PROPS_WINDOW_PAGE_TROUBLESHOOTING_LOG,
	BOXES_PROPS_WINDOW_PAGE_FILE_CHOOSER
} BoxesPropsWindowPage;

struct _BoxesPropertiesToolbarPrivate {
	BoxesPropsWindowPage _page;
	BoxesEditableEntry* title_entry;
	GtkButton* file_chooser_open_button;
	BoxesAppWindow* window;
	BoxesPropertiesWindow* props_window;
	BoxesCollectionItem* item;
	gulong item_name_id;
};

struct _Block74Data {
	int _ref_count_;
	BoxesPropertiesToolbar* self;
	GtkFileChooserWidget* file_chooser;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesPropertiesWindow {
	GtkWindow parent_instance;
	BoxesPropertiesWindowPrivate * priv;
	GtkStack* view;
	BoxesProperties* properties;
	BoxesTroubleshootLog* troubleshoot_log;
	GtkFileChooserWidget* file_chooser;
	BoxesPropertiesToolbar* topbar;
	BoxesNotificationbar* notificationbar;
};

struct _BoxesPropertiesWindowClass {
	GtkWindowClass parent_class;
};


static gpointer boxes_properties_toolbar_parent_class = NULL;

GType boxes_properties_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_props_window_page_get_type (void) G_GNUC_CONST;
GType boxes_editable_entry_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_properties_window_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
#define BOXES_PROPERTIES_TOOLBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbarPrivate))
enum  {
	BOXES_PROPERTIES_TOOLBAR_DUMMY_PROPERTY,
	BOXES_PROPERTIES_TOOLBAR_PAGE
};
void boxes_properties_toolbar_setup_ui (BoxesPropertiesToolbar* self, BoxesAppWindow* window, BoxesPropertiesWindow* props_window);
static Block74Data* block74_data_ref (Block74Data* _data74_);
static void block74_data_unref (void * _userdata_);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_troubleshoot_log_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
static void __lambda110_ (Block74Data* _data74_);
static void ___lambda110__gtk_file_chooser_selection_changed (GtkFileChooser* _sender, gpointer self);
static void boxes_properties_toolbar_ui_state_changed (BoxesPropertiesToolbar* self);
static void _boxes_properties_toolbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_properties_toolbar_click_back_button (BoxesPropertiesToolbar* self);
BoxesPropsWindowPage boxes_properties_toolbar_get_page (BoxesPropertiesToolbar* self);
static void boxes_properties_toolbar_on_troubleshooting_back_clicked (BoxesPropertiesToolbar* self);
void boxes_properties_window_set_page (BoxesPropertiesWindow* self, BoxesPropsWindowPage value);
static void _boxes_properties_toolbar_on_troubleshooting_back_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_properties_toolbar_on_copy_clipboard_clicked (BoxesPropertiesToolbar* self);
void boxes_properties_window_copy_troubleshoot_log_to_clipboard (BoxesPropertiesWindow* self);
static void _boxes_properties_toolbar_on_copy_clipboard_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_properties_toolbar_on_file_chooser_cancel_clicked (BoxesPropertiesToolbar* self);
static void _boxes_properties_toolbar_on_file_chooser_cancel_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_properties_toolbar_on_file_chooser_open_clicked (BoxesPropertiesToolbar* self);
static void _boxes_properties_toolbar_on_file_chooser_open_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_properties_toolbar_on_title_entry_changed (BoxesPropertiesToolbar* self);
BoxesCollectionItem* boxes_app_window_get_current_item (BoxesAppWindow* self);
const gchar* boxes_editable_entry_get_text (BoxesEditableEntry* self);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
static void _boxes_properties_toolbar_on_title_entry_changed_boxes_editable_entry_editing_done (BoxesEditableEntry* _sender, gpointer self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void ___lambda111_ (BoxesPropertiesToolbar* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_editable_entry_set_text (BoxesEditableEntry* self, const gchar* value);
static void ____lambda111__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
BoxesPropertiesToolbar* boxes_properties_toolbar_new (void);
BoxesPropertiesToolbar* boxes_properties_toolbar_construct (GType object_type);
void boxes_properties_toolbar_set_page (BoxesPropertiesToolbar* self, BoxesPropsWindowPage value);
static GObject * boxes_properties_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void boxes_properties_toolbar_finalize (GObject* obj);
static void _vala_boxes_properties_toolbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_properties_toolbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

extern const gchar* BOXES_PROPERTIES_WINDOW_page_names[3];

static Block74Data* block74_data_ref (Block74Data* _data74_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_atomic_int_inc (&_data74_->_ref_count_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return _data74_;
#line 244 "properties-toolbar.c"
}


static void block74_data_unref (void * _userdata_) {
	Block74Data* _data74_;
	_data74_ = (Block74Data*) _userdata_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	if (g_atomic_int_dec_and_test (&_data74_->_ref_count_)) {
#line 253 "properties-toolbar.c"
		BoxesPropertiesToolbar* self;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		self = _data74_->self;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_g_object_unref0 (_data74_->file_chooser);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_g_object_unref0 (self);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		g_slice_free (Block74Data, _data74_);
#line 263 "properties-toolbar.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 271 "properties-toolbar.c"
}


static void __lambda110_ (Block74Data* _data74_) {
	BoxesPropertiesToolbar* self;
	gchar* path = NULL;
	gchar* _tmp0_ = NULL;
	GtkButton* _tmp1_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self = _data74_->self;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = gtk_file_chooser_get_filename ((GtkFileChooser*) _data74_->file_chooser);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	path = _tmp0_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = self->priv->file_chooser_open_button;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, path != NULL);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_free0 (path);
#line 292 "properties-toolbar.c"
}


static void ___lambda110__gtk_file_chooser_selection_changed (GtkFileChooser* _sender, gpointer self) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	__lambda110_ (self);
#line 299 "properties-toolbar.c"
}


static void _boxes_properties_toolbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_ui_state_changed ((BoxesPropertiesToolbar*) self);
#line 306 "properties-toolbar.c"
}


void boxes_properties_toolbar_setup_ui (BoxesPropertiesToolbar* self, BoxesAppWindow* window, BoxesPropertiesWindow* props_window) {
	Block74Data* _data74_;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesPropertiesWindow* _tmp2_ = NULL;
	BoxesPropertiesWindow* _tmp3_ = NULL;
	GtkFileChooserWidget* _tmp4_ = NULL;
	GtkFileChooserWidget* _tmp5_ = NULL;
	BoxesAppWindow* _tmp6_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (window != NULL);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (props_window != NULL);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_data74_ = g_slice_new0 (Block74Data);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_data74_->_ref_count_ = 1;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_data74_->self = g_object_ref (self);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = window;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->window);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self->priv->window = _tmp1_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = props_window;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self->priv->props_window = _tmp2_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = props_window;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp4_ = _tmp3_->file_chooser;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_data74_->file_chooser = _tmp5_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_signal_connect_data ((GtkFileChooser*) _data74_->file_chooser, "selection-changed", (GCallback) ___lambda110__gtk_file_chooser_selection_changed, block74_data_ref (_data74_), (GClosureNotify) block74_data_unref, 0);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp6_ = window;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_signal_connect_object ((GObject*) _tmp6_, "notify::ui-state", (GCallback) _boxes_properties_toolbar_ui_state_changed_g_object_notify, self, 0);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	block74_data_unref (_data74_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_data74_ = NULL;
#line 361 "properties-toolbar.c"
}


void boxes_properties_toolbar_click_back_button (BoxesPropertiesToolbar* self) {
	BoxesPropsWindowPage _tmp0_ = 0;
	BoxesPropsWindowPage _tmp1_ = 0;
	GtkButton* _tmp2_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = boxes_properties_toolbar_get_page (self);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = _tmp0_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	if (_tmp1_ != BOXES_PROPS_WINDOW_PAGE_TROUBLESHOOTING_LOG) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		return;
#line 379 "properties-toolbar.c"
	}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = self->troubleshooting_back_button;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_button_clicked (_tmp2_);
#line 385 "properties-toolbar.c"
}


static void boxes_properties_toolbar_on_troubleshooting_back_clicked (BoxesPropertiesToolbar* self) {
	BoxesPropsWindowPage _tmp0_ = 0;
	BoxesPropsWindowPage _tmp1_ = 0;
	BoxesPropertiesWindow* _tmp2_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = boxes_properties_toolbar_get_page (self);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = _tmp0_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_vala_return_if_fail (_tmp1_ == BOXES_PROPS_WINDOW_PAGE_TROUBLESHOOTING_LOG, "page == PropsWindowPage.TROUBLESHOOTING_LOG");
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = self->priv->props_window;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_window_set_page (_tmp2_, BOXES_PROPS_WINDOW_PAGE_MAIN);
#line 405 "properties-toolbar.c"
}


static void _boxes_properties_toolbar_on_troubleshooting_back_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_on_troubleshooting_back_clicked ((BoxesPropertiesToolbar*) self);
#line 412 "properties-toolbar.c"
}


static void boxes_properties_toolbar_on_copy_clipboard_clicked (BoxesPropertiesToolbar* self) {
	BoxesPropsWindowPage _tmp0_ = 0;
	BoxesPropsWindowPage _tmp1_ = 0;
	BoxesPropertiesWindow* _tmp2_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = boxes_properties_toolbar_get_page (self);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = _tmp0_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_vala_return_if_fail (_tmp1_ == BOXES_PROPS_WINDOW_PAGE_TROUBLESHOOTING_LOG, "page == PropsWindowPage.TROUBLESHOOTING_LOG");
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = self->priv->props_window;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_window_copy_troubleshoot_log_to_clipboard (_tmp2_);
#line 432 "properties-toolbar.c"
}


static void _boxes_properties_toolbar_on_copy_clipboard_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_on_copy_clipboard_clicked ((BoxesPropertiesToolbar*) self);
#line 439 "properties-toolbar.c"
}


static void boxes_properties_toolbar_on_file_chooser_cancel_clicked (BoxesPropertiesToolbar* self) {
	BoxesPropsWindowPage _tmp0_ = 0;
	BoxesPropsWindowPage _tmp1_ = 0;
	BoxesPropertiesWindow* _tmp2_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = boxes_properties_toolbar_get_page (self);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = _tmp0_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_vala_return_if_fail (_tmp1_ == BOXES_PROPS_WINDOW_PAGE_FILE_CHOOSER, "page == PropsWindowPage.FILE_CHOOSER");
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = self->priv->props_window;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_window_set_page (_tmp2_, BOXES_PROPS_WINDOW_PAGE_MAIN);
#line 459 "properties-toolbar.c"
}


static void _boxes_properties_toolbar_on_file_chooser_cancel_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_on_file_chooser_cancel_clicked ((BoxesPropertiesToolbar*) self);
#line 466 "properties-toolbar.c"
}


static void boxes_properties_toolbar_on_file_chooser_open_clicked (BoxesPropertiesToolbar* self) {
	BoxesPropsWindowPage _tmp0_ = 0;
	BoxesPropsWindowPage _tmp1_ = 0;
	GtkFileChooserWidget* file_chooser = NULL;
	BoxesPropertiesWindow* _tmp2_ = NULL;
	GtkFileChooserWidget* _tmp3_ = NULL;
	GtkFileChooserWidget* _tmp4_ = NULL;
	GFile* file = NULL;
	GtkFileChooserWidget* _tmp5_ = NULL;
	GFile* _tmp6_ = NULL;
	GFile* _tmp7_ = NULL;
	GFileType file_type = 0;
	GFile* _tmp8_ = NULL;
	GFileType _tmp9_ = 0;
	GFileType _tmp10_ = 0;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = boxes_properties_toolbar_get_page (self);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = _tmp0_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_vala_return_if_fail (_tmp1_ == BOXES_PROPS_WINDOW_PAGE_FILE_CHOOSER, "page == PropsWindowPage.FILE_CHOOSER");
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = self->priv->props_window;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = _tmp2_->file_chooser;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	file_chooser = _tmp4_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp5_ = file_chooser;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp6_ = gtk_file_chooser_get_file ((GtkFileChooser*) _tmp5_);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	file = _tmp6_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp7_ = file;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_vala_assert (_tmp7_ != NULL, "file != null");
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp8_ = file;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp9_ = g_file_query_file_type (_tmp8_, G_FILE_QUERY_INFO_NONE, NULL);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	file_type = _tmp9_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp10_ = file_type;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	switch (_tmp10_) {
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		case G_FILE_TYPE_REGULAR:
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		case G_FILE_TYPE_SYMBOLIC_LINK:
#line 525 "properties-toolbar.c"
		{
			GtkFileChooserWidget* _tmp11_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			_tmp11_ = file_chooser;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			g_signal_emit_by_name ((GtkFileChooser*) _tmp11_, "file-activated");
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			break;
#line 534 "properties-toolbar.c"
		}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		case G_FILE_TYPE_DIRECTORY:
#line 538 "properties-toolbar.c"
		{
			GtkFileChooserWidget* _tmp12_ = NULL;
			GFile* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			_tmp12_ = file_chooser;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			_tmp13_ = file;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			_tmp14_ = g_file_get_path (_tmp13_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			_tmp15_ = _tmp14_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			gtk_file_chooser_set_current_folder ((GtkFileChooser*) _tmp12_, _tmp15_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			_g_free0 (_tmp15_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			break;
#line 558 "properties-toolbar.c"
		}
		default:
		{
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			g_debug ("properties-toolbar.vala:92: Unknown file type selected");
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
			break;
#line 566 "properties-toolbar.c"
		}
	}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (file);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (file_chooser);
#line 573 "properties-toolbar.c"
}


static void _boxes_properties_toolbar_on_file_chooser_open_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_on_file_chooser_open_clicked ((BoxesPropertiesToolbar*) self);
#line 580 "properties-toolbar.c"
}


static void boxes_properties_toolbar_on_title_entry_changed (BoxesPropertiesToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesEditableEntry* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = self->priv->window;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = boxes_app_window_get_current_item (_tmp0_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = _tmp1_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = self->priv->title_entry;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp4_ = boxes_editable_entry_get_text (_tmp3_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp5_ = _tmp4_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_collection_item_set_name (_tmp2_, _tmp5_);
#line 607 "properties-toolbar.c"
}


static void _boxes_properties_toolbar_on_title_entry_changed_boxes_editable_entry_editing_done (BoxesEditableEntry* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_on_title_entry_changed ((BoxesPropertiesToolbar*) self);
#line 614 "properties-toolbar.c"
}


static void ___lambda111_ (BoxesPropertiesToolbar* self) {
	BoxesEditableEntry* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = self->priv->title_entry;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = self->priv->item;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = boxes_collection_item_get_name (_tmp1_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = _tmp2_;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_editable_entry_set_text (_tmp0_, _tmp3_);
#line 633 "properties-toolbar.c"
}


static void ____lambda111__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	___lambda111_ ((BoxesPropertiesToolbar*) self);
#line 640 "properties-toolbar.c"
}


static void boxes_properties_toolbar_ui_state_changed (BoxesPropertiesToolbar* self) {
	gulong _tmp0_ = 0UL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesUIState _tmp4_ = 0;
	BoxesUIState _tmp5_ = 0;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = self->priv->item_name_id;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 655 "properties-toolbar.c"
		BoxesCollectionItem* _tmp1_ = NULL;
		gulong _tmp2_ = 0UL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp1_ = self->priv->item;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp2_ = self->priv->item_name_id;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		self->priv->item_name_id = (gulong) 0;
#line 666 "properties-toolbar.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp3_ = self->priv->window;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp4_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp3_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp5_ = _tmp4_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	if (_tmp5_ == BOXES_UI_STATE_PROPERTIES) {
#line 676 "properties-toolbar.c"
		BoxesAppWindow* _tmp6_ = NULL;
		BoxesCollectionItem* _tmp7_ = NULL;
		BoxesCollectionItem* _tmp8_ = NULL;
		BoxesCollectionItem* _tmp9_ = NULL;
		BoxesCollectionItem* _tmp10_ = NULL;
		gulong _tmp11_ = 0UL;
		BoxesEditableEntry* _tmp12_ = NULL;
		BoxesCollectionItem* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp6_ = self->priv->window;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp7_ = boxes_app_window_get_current_item (_tmp6_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp8_ = _tmp7_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp9_ = _g_object_ref0 (_tmp8_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_g_object_unref0 (self->priv->item);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		self->priv->item = _tmp9_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp10_ = self->priv->item;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp11_ = g_signal_connect_object ((GObject*) _tmp10_, "notify::name", (GCallback) ____lambda111__g_object_notify, self, 0);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		self->priv->item_name_id = _tmp11_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp12_ = self->priv->title_entry;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp13_ = self->priv->item;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp14_ = boxes_collection_item_get_name (_tmp13_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		_tmp15_ = _tmp14_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		boxes_editable_entry_set_text (_tmp12_, _tmp15_);
#line 715 "properties-toolbar.c"
	}
}


BoxesPropertiesToolbar* boxes_properties_toolbar_construct (GType object_type) {
	BoxesPropertiesToolbar * self = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self = (BoxesPropertiesToolbar*) g_object_new (object_type, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return self;
#line 726 "properties-toolbar.c"
}


BoxesPropertiesToolbar* boxes_properties_toolbar_new (void) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return boxes_properties_toolbar_construct (BOXES_TYPE_PROPERTIES_TOOLBAR);
#line 733 "properties-toolbar.c"
}


BoxesPropsWindowPage boxes_properties_toolbar_get_page (BoxesPropertiesToolbar* self) {
	BoxesPropsWindowPage result;
	BoxesPropsWindowPage _tmp0_ = 0;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = self->priv->_page;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	result = _tmp0_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return result;
#line 748 "properties-toolbar.c"
}


void boxes_properties_toolbar_set_page (BoxesPropertiesToolbar* self, BoxesPropsWindowPage value) {
	BoxesPropsWindowPage _tmp0_ = 0;
	BoxesPropsWindowPage _tmp1_ = 0;
	const gchar* _tmp2_ = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = value;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self->priv->_page = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = value;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp2_ = BOXES_PROPERTIES_WINDOW_page_names[_tmp1_];
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp2_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_object_notify ((GObject *) self, "page");
#line 770 "properties-toolbar.c"
}


static GObject * boxes_properties_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesPropertiesToolbar * self;
	GtkHeaderBar* _tmp0_ = NULL;
	BoxesEditableEntry* _tmp1_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_properties_toolbar_parent_class);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp0_ = self->main;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_tmp1_ = self->priv->title_entry;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_header_bar_set_custom_title (_tmp0_, (GtkWidget*) _tmp1_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	return obj;
#line 794 "properties-toolbar.c"
}


static void boxes_properties_toolbar_class_init (BoxesPropertiesToolbarClass * klass) {
	gint BoxesPropertiesToolbar_private_offset;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	boxes_properties_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesPropertiesToolbarPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_properties_toolbar_get_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_properties_toolbar_set_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_properties_toolbar_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_properties_toolbar_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_PROPERTIES_TOOLBAR_PAGE, g_param_spec_enum ("page", "page", "page", BOXES_TYPE_PROPS_WINDOW_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	BoxesPropertiesToolbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/properties-toolbar.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "main", FALSE, G_STRUCT_OFFSET (BoxesPropertiesToolbar, main));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "troubleshooting_back_button", FALSE, G_STRUCT_OFFSET (BoxesPropertiesToolbar, troubleshooting_back_button));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "title_entry", FALSE, BoxesPropertiesToolbar_private_offset + G_STRUCT_OFFSET (BoxesPropertiesToolbarPrivate, title_entry));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "file_chooser_open_button", FALSE, BoxesPropertiesToolbar_private_offset + G_STRUCT_OFFSET (BoxesPropertiesToolbarPrivate, file_chooser_open_button));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_troubleshooting_back_clicked", G_CALLBACK(_boxes_properties_toolbar_on_troubleshooting_back_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_copy_clipboard_clicked", G_CALLBACK(_boxes_properties_toolbar_on_copy_clipboard_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_file_chooser_cancel_clicked", G_CALLBACK(_boxes_properties_toolbar_on_file_chooser_cancel_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_file_chooser_open_clicked", G_CALLBACK(_boxes_properties_toolbar_on_file_chooser_open_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_title_entry_changed", G_CALLBACK(_boxes_properties_toolbar_on_title_entry_changed_boxes_editable_entry_editing_done));
#line 836 "properties-toolbar.c"
}


static void boxes_properties_toolbar_instance_init (BoxesPropertiesToolbar * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self->priv = BOXES_PROPERTIES_TOOLBAR_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	g_type_ensure (BOXES_TYPE_EDITABLE_ENTRY);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 847 "properties-toolbar.c"
}


static void boxes_properties_toolbar_finalize (GObject* obj) {
	BoxesPropertiesToolbar * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->main);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->troubleshooting_back_button);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->title_entry);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->file_chooser_open_button);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->window);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	_g_object_unref0 (self->priv->item);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	G_OBJECT_CLASS (boxes_properties_toolbar_parent_class)->finalize (obj);
#line 869 "properties-toolbar.c"
}


GType boxes_properties_toolbar_get_type (void) {
	static volatile gsize boxes_properties_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_properties_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPropertiesToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_properties_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPropertiesToolbar), 0, (GInstanceInitFunc) boxes_properties_toolbar_instance_init, NULL };
		GType boxes_properties_toolbar_type_id;
		boxes_properties_toolbar_type_id = g_type_register_static (gtk_stack_get_type (), "BoxesPropertiesToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_properties_toolbar_type_id__volatile, boxes_properties_toolbar_type_id);
	}
	return boxes_properties_toolbar_type_id__volatile;
}


static void _vala_boxes_properties_toolbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesPropertiesToolbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		case BOXES_PROPERTIES_TOOLBAR_PAGE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		g_value_set_enum (value, boxes_properties_toolbar_get_page (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		break;
#line 896 "properties-toolbar.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		break;
#line 902 "properties-toolbar.c"
	}
}


static void _vala_boxes_properties_toolbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesPropertiesToolbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_PROPERTIES_TOOLBAR, BoxesPropertiesToolbar);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		case BOXES_PROPERTIES_TOOLBAR_PAGE:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		boxes_properties_toolbar_set_page (self, g_value_get_enum (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		break;
#line 918 "properties-toolbar.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/properties-toolbar.vala"
		break;
#line 924 "properties-toolbar.c"
	}
}



