/* vm-creator.c generated by valac 0.32.0.73-ab1d1, the Vala compiler
 * generated from vm-creator.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gtk/gtk.h>
#include <libcommon.h>
#include <osinfo/osinfo.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <glib/gstdio.h>
#include <glib/gi18n-lib.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
typedef struct _BoxesVMCreatorPrivate BoxesVMCreatorPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))
typedef struct _Block85Data Block85Data;
typedef struct _Block86Data Block86Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;

#define BOXES_TYPE_LIBVIRT_BROKER (boxes_libvirt_broker_get_type ())
#define BOXES_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker))
#define BOXES_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))
#define BOXES_IS_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_IS_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_LIBVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))

typedef struct _BoxesLibvirtBroker BoxesLibvirtBroker;
typedef struct _BoxesLibvirtBrokerClass BoxesLibvirtBrokerClass;
typedef struct _BoxesVmCreatorCreateVmData BoxesVmCreatorCreateVmData;
typedef struct _Block87Data Block87Data;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _Block88Data Block88Data;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesVmCreatorContinueInstallationData BoxesVmCreatorContinueInstallationData;
typedef struct _Block89Data Block89Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesVmCreatorTryCreateSnapshotData BoxesVmCreatorTryCreateSnapshotData;
typedef struct _BoxesVmCreatorCreateDomainConfigData BoxesVmCreatorCreateDomainConfigData;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
typedef struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData BoxesVmCreatorCreateDomainNameAndTitleFromMediaData;
typedef struct _BoxesVmCreatorCreateTargetVolumeData BoxesVmCreatorCreateTargetVolumeData;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesUnattendedInstallerPrivate BoxesUnattendedInstallerPrivate;

#define BOXES_TYPE_UNATTENDED_SETUP_BOX (boxes_unattended_setup_box_get_type ())
#define BOXES_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox))
#define BOXES_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))
#define BOXES_IS_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_IS_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_UNATTENDED_SETUP_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))

typedef struct _BoxesUnattendedSetupBox BoxesUnattendedSetupBox;
typedef struct _BoxesUnattendedSetupBoxClass BoxesUnattendedSetupBoxClass;
typedef struct _BoxesParamSpecVMCreator BoxesParamSpecVMCreator;

struct _BoxesVMCreator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesVMCreatorPrivate * priv;
};

struct _BoxesVMCreatorClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesVMCreator *self);
	void (*launch_vm) (BoxesVMCreator* self, BoxesLibvirtMachine* machine, gint64 access_last_time, GError** error);
	void (*continue_installation) (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*continue_installation_finish) (BoxesVMCreator* self, GAsyncResult* _res_);
	void (*create_domain_config) (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GVirConfigDomain* (*create_domain_config_finish) (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
	void (*create_domain_base_name_and_title) (BoxesVMCreator* self, gchar** base_name, gchar** base_title);
};

struct _BoxesVMCreatorPrivate {
	BoxesInstallerMedia* _install_media;
	gulong state_changed_id;
	guint _num_reboots;
};

struct _Block85Data {
	int _ref_count_;
	BoxesVMCreator* self;
	gpointer _async_data_;
};

struct _Block86Data {
	int _ref_count_;
	Block85Data * _data85_;
	gulong handler;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gboolean (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesVmCreatorCreateVmData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	GCancellable* cancellable;
	BoxesLibvirtMachine* result;
	Block85Data* _data85_;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	gboolean _tmp3_;
	Block86Data* _data86_;
	BoxesApp* _tmp4_;
	gulong _tmp5_;
	gchar* title;
	gchar* name;
	gchar* _tmp6_;
	gchar* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	const gchar* _tmp9_;
	GCancellable* _tmp10_;
	GVirStorageVol* volume;
	const gchar* _tmp11_;
	BoxesInstallerMedia* _tmp12_;
	OsinfoResources* _tmp13_;
	gint64 _tmp14_;
	gint64 _tmp15_;
	GVirStorageVol* _tmp16_;
	GVirConfigDomain* config;
	const gchar* _tmp17_;
	const gchar* _tmp18_;
	GVirStorageVol* _tmp19_;
	GCancellable* _tmp20_;
	GVirConfigDomain* _tmp21_;
	GVirDomain* domain;
	GVirConnection* _tmp22_;
	GVirConnection* _tmp23_;
	GVirConnection* _tmp24_;
	GVirConfigDomain* _tmp25_;
	GVirDomain* _tmp26_;
	GVirDomain* _tmp27_;
	BoxesLibvirtMachine* machine;
	BoxesLibvirtBroker* _tmp28_;
	BoxesLibvirtBroker* _tmp29_;
	BoxesApp* _tmp30_;
	BoxesCollectionSource* _tmp31_;
	BoxesCollectionSource* _tmp32_;
	BoxesApp* _tmp33_;
	GVirConnection* _tmp34_;
	GVirConnection* _tmp35_;
	GVirConnection* _tmp36_;
	GVirDomain* _tmp37_;
	BoxesLibvirtMachine* _tmp38_;
	BoxesLibvirtMachine* _tmp39_;
	BoxesLibvirtMachine* _tmp40_;
	GError * _inner_error_;
};

struct _Block87Data {
	int _ref_count_;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
};

struct _Block88Data {
	int _ref_count_;
	Block87Data * _data87_;
	gulong signal_id;
	BoxesAppWindow* window;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*clone) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*clone_finish) (BoxesMachine* self, GAsyncResult* _res_);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_can_restart) (BoxesMachine* self);
	gboolean (*get_can_clone) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesVmCreatorContinueInstallationData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
	BoxesMediaManager* _tmp0_;
	BoxesMediaManager* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GVirConfigDomain* _tmp3_;
	GVirConfigDomain* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	GVirConfigDomain* _tmp8_;
	GVirConfigDomain* _tmp9_;
	guint _tmp10_;
	gchar* name;
	BoxesLibvirtMachine* _tmp11_;
	GVirDomain* _tmp12_;
	GVirDomain* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesLibvirtMachine* _tmp17_;
	BoxesInstallerMedia* _tmp18_;
	const gchar* _tmp19_;
	gboolean _tmp20_;
	BoxesInstallerMedia* _tmp21_;
	const gchar* _tmp22_;
	BoxesLibvirtMachine* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	BoxesApp* _tmp26_;
	BoxesLibvirtMachine* _tmp27_;
	BoxesInstallerMedia* _tmp28_;
	const gchar* _tmp29_;
	BoxesLibvirtMachine* _tmp30_;
	gulong _tmp31_;
	BoxesLibvirtMachine* _tmp32_;
	BoxesLibvirtMachine* _tmp33_;
	gboolean _tmp34_;
	BoxesLibvirtMachine* _tmp35_;
	BoxesMachineMachineState _tmp36_;
	BoxesMachineMachineState _tmp37_;
	BoxesLibvirtMachine* _tmp38_;
	GVirConfigDomain* _tmp39_;
	GVirConfigDomain* _tmp40_;
	gboolean _tmp41_;
	BoxesLibvirtMachine* _tmp42_;
	GVirDomain* _tmp43_;
	GVirDomain* _tmp44_;
	GError* e;
	BoxesLibvirtMachine* _tmp45_;
	const gchar* _tmp46_;
	const gchar* _tmp47_;
	GError* _tmp48_;
	const gchar* _tmp49_;
	GError * _inner_error_;
};

struct _Block89Data {
	int _ref_count_;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
};

typedef void (*BoxesAppUndoNotifyCallback) (void* user_data);
struct _BoxesVmCreatorTryCreateSnapshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
	BoxesLibvirtMachine* _tmp0_;
	GVirDomainSnapshot* _tmp1_;
	GVirDomainSnapshot* _tmp2_;
	GError* _error_;
	BoxesLibvirtMachine* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	GError* _tmp6_;
	const gchar* _tmp7_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_VM_CONFIGURATOR_ERROR_NO_GUEST_CAPS
} BoxesVMConfiguratorError;
#define BOXES_VM_CONFIGURATOR_ERROR boxes_vm_configurator_error_quark ()
struct _BoxesVmCreatorCreateDomainConfigData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gchar* title;
	GVirStorageVol* volume;
	GCancellable* cancellable;
	GVirConfigDomain* result;
	GVirConfigCapabilities* caps;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	GCancellable* _tmp3_;
	GVirConfigCapabilities* _tmp4_;
	GVirConfigCapabilities* _tmp5_;
	const gchar* _tmp6_;
	GVirStorageVol* _tmp7_;
	const gchar* _tmp8_;
	GVirConfigDomain* config;
	BoxesInstallerMedia* _tmp9_;
	GVirConfigCapabilities* _tmp10_;
	GVirConfigDomain* _tmp11_;
	GVirConfigDomain* _tmp12_;
	const gchar* _tmp13_;
	GVirConfigDomain* _tmp14_;
	const gchar* _tmp15_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gchar* title;
	gchar* base_name;
	gchar* base_title;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GVirStoragePool* pool;
	GVirConnection* _tmp4_;
	GVirConnection* _tmp5_;
	GVirConnection* _tmp6_;
	GVirStoragePool* _tmp7_;
	GVirStoragePool* _tmp8_;
	gint i;
	gboolean _tmp9_;
	gint _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	GVirConnection* _tmp13_;
	GVirConnection* _tmp14_;
	GVirConnection* _tmp15_;
	const gchar* _tmp16_;
	GVirDomain* _tmp17_;
	GVirDomain* _tmp18_;
	gboolean _tmp19_;
	GVirConnection* _tmp20_;
	GVirConnection* _tmp21_;
	GVirConnection* _tmp22_;
	const gchar* _tmp23_;
	GVirDomain* _tmp24_;
	GVirDomain* _tmp25_;
	const gchar* _tmp26_;
	GVirStorageVol* _tmp27_;
	GVirStorageVol* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gint _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gint _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorCreateTargetVolumeData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gint64 storage;
	GVirStorageVol* result;
	GVirStoragePool* pool;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	GVirStoragePool* _tmp3_;
	GVirStoragePool* _tmp4_;
	GVirConfigStorageVol* config;
	const gchar* _tmp5_;
	gint64 _tmp6_;
	GVirConfigStorageVol* _tmp7_;
	const gchar* _tmp8_;
	GVirStorageVol* volume;
	GVirStoragePool* _tmp9_;
	GVirConfigStorageVol* _tmp10_;
	GVirStorageVol* _tmp11_;
	const gchar* _tmp12_;
	GError * _inner_error_;
};

struct _BoxesUnattendedInstaller {
	BoxesInstallerMedia parent_instance;
	BoxesUnattendedInstallerPrivate * priv;
	BoxesUnattendedSetupBox* setup_box;
	GFile* disk_file;
	GFile* secondary_disk_file;
	GFile* kernel_file;
	GFile* initrd_file;
	OsinfoInstallConfig* config;
	OsinfoInstallScriptList* scripts;
};

struct _BoxesUnattendedInstallerClass {
	BoxesInstallerMediaClass parent_class;
};

struct _BoxesParamSpecVMCreator {
	GParamSpec parent_instance;
};


static gpointer boxes_vm_creator_parent_class = NULL;
extern BoxesApp* boxes_app_app;

gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
#define BOXES_VM_CREATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorPrivate))
enum  {
	BOXES_VM_CREATOR_DUMMY_PROPERTY
};
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_clean_up (BoxesInstallerMedia* self);
#define BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT 99
BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media);
BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media);
void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value);
BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine);
BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine);
void boxes_vm_creator_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_vm_creator_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_);
static void boxes_vm_creator_create_vm_data_free (gpointer _data);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_);
static Block85Data* block85_data_ref (Block85Data* _data85_);
static void block85_data_unref (void * _userdata_);
GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self);
static Block86Data* block86_data_ref (Block86Data* _data86_);
static void block86_data_unref (void * _userdata_);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void ___lambda45_ (Block86Data* _data86_);
static void ____lambda45__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** name, gchar** title, GError** error);
static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation_finish (BoxesInstallerMedia* self, GAsyncResult* _res_);
static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
void boxes_vm_creator_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirConfigDomain* boxes_vm_creator_create_domain_config_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
GType boxes_broker_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_broker_get_type (void) G_GNUC_CONST;
BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void);
void boxes_libvirt_broker_add_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_libvirt_broker_add_domain_finish (BoxesLibvirtBroker* self, GAsyncResult* _res_, GError** error);
BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self);
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
void boxes_libvirt_machine_set_vm_creator (BoxesLibvirtMachine* self, BoxesVMCreator* value);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, gint64 access_last_time, GError** error);
static void boxes_vm_creator_real_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, gint64 access_last_time, GError** error);
static Block87Data* block87_data_ref (Block87Data* _data87_);
static void block87_data_unref (void * _userdata_);
gboolean boxes_vm_creator_get_express_install (BoxesVMCreator* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
static Block88Data* block88_data_ref (Block88Data* _data88_);
static void block88_data_unref (void * _userdata_);
BoxesAppWindow* boxes_app_get_main_window (BoxesApp* self);
static void ___lambda46_ (Block88Data* _data88_);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item);
static void ____lambda46__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec);
static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void boxes_vm_creator_real_continue_installation_data_free (gpointer _data);
static void boxes_vm_creator_real_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_vm_creator_real_continue_installation_co (BoxesVmCreatorContinueInstallationData* _data_);
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
BoxesMediaManager* boxes_media_manager_get_instance (void);
void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_vm_creator_continue_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
guint boxes_vm_configurator_get_num_reboots (GVirConfigDomain* domain);
static void boxes_vm_creator_set_num_reboots (BoxesVMCreator* self, guint value);
void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_installer_media_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
static Block89Data* block89_data_ref (Block89Data* _data89_);
static void block89_data_unref (void * _userdata_);
gboolean boxes_machine_get_is_on (BoxesMachine* self);
gboolean boxes_machine_get_deleted (BoxesMachine* self);
static void boxes_vm_creator_increment_num_reboots (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
void boxes_app_notify_machine_installed (BoxesApp* self, BoxesMachine* machine);
void boxes_machine_schedule_autosave (BoxesMachine* self);
static void boxes_vm_creator_try_create_snapshot (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_vm_creator_try_create_snapshot_finish (BoxesVMCreator* self, GAsyncResult* _res_);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
static void ____lambda51_ (Block89Data* _data89_);
static void _____lambda51__boxes_app_undo_notify_callback (gpointer self);
void boxes_app_delete_machines_undoable (BoxesApp* self, GList* items, const gchar* message, BoxesAppUndoNotifyCallback undo_notify_callback, void* undo_notify_callback_target, GDestroyNotify undo_notify_callback_target_destroy_notify);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_vm_creator_try_create_snapshot_data_free (gpointer _data);
static gboolean boxes_vm_creator_try_create_snapshot_co (BoxesVmCreatorTryCreateSnapshotData* _data_);
void boxes_libvirt_machine_create_snapshot (BoxesLibvirtMachine* self, const gchar* description_prefix, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirDomainSnapshot* boxes_libvirt_machine_create_snapshot_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static void boxes_vm_creator_try_create_snapshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_vm_configurator_post_install_setup (GVirConfigDomain* domain, BoxesInstallerMedia* install_media);
static void boxes_vm_creator_real_create_domain_config_data_free (gpointer _data);
static void boxes_vm_creator_real_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_vm_creator_real_create_domain_config_co (BoxesVmCreatorCreateDomainConfigData* _data_);
static void boxes_vm_creator_create_domain_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GQuark boxes_vm_configurator_error_quark (void);
GVirConfigDomain* boxes_vm_configurator_create_domain_config (BoxesInstallerMedia* install_media, const gchar* target_path, GVirConfigCapabilities* caps, GError** error);
void boxes_vm_creator_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title);
static void boxes_vm_creator_real_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title);
static guint boxes_vm_creator_get_num_reboots (BoxesVMCreator* self);
void boxes_vm_configurator_set_num_reboots (GVirConfigDomain* domain, BoxesInstallerMedia* install_media, guint num_reboots);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_);
void boxes_ensure_storage_pool (GVirConnection* connection, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirStoragePool* boxes_ensure_storage_pool_finish (GAsyncResult* _res_, GError** error);
static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_vm_creator_create_target_volume_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_);
static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GVirConfigStorageVol* boxes_vm_configurator_create_volume_config (const gchar* name, gint64 storage, GError** error);
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
GType boxes_unattended_setup_box_get_type (void) G_GNUC_CONST;
gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self);
static void boxes_vm_creator_finalize (BoxesVMCreator* obj);


BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media) {
	BoxesVMCreator* self = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (install_media != NULL, NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = install_media;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_install_media (self, _tmp0_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self;
#line 817 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct (BOXES_TYPE_VM_CREATOR, install_media);
#line 824 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesVMCreator* self = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_continue_installation (self, _tmp0_, NULL, NULL);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self;
#line 841 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine) {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct_for_install_completion (BOXES_TYPE_VM_CREATOR, machine);
#line 848 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_data_free (gpointer _data) {
	BoxesVmCreatorCreateVmData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateVmData, _data_);
#line 863 "vm-creator.c"
}


static gpointer _boxes_vm_creator_ref0 (gpointer self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self ? boxes_vm_creator_ref (self) : NULL;
#line 870 "vm-creator.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self ? g_object_ref (self) : NULL;
#line 877 "vm-creator.c"
}


void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateVmData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_vm);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_vm_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->cancellable = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 906 "vm-creator.c"
}


BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachine* result;
	BoxesVmCreatorCreateVmData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 917 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 927 "vm-creator.c"
}


static Block85Data* block85_data_ref (Block85Data* _data85_) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data85_->_ref_count_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data85_;
#line 936 "vm-creator.c"
}


static void block85_data_unref (void * _userdata_) {
	Block85Data* _data85_;
	_data85_ = (Block85Data*) _userdata_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data85_->_ref_count_)) {
#line 945 "vm-creator.c"
		BoxesVMCreator* self;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data85_->self;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block85Data, _data85_);
#line 953 "vm-creator.c"
	}
}


static Block86Data* block86_data_ref (Block86Data* _data86_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data86_->_ref_count_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data86_;
#line 963 "vm-creator.c"
}


static void block86_data_unref (void * _userdata_) {
	Block86Data* _data86_;
	_data86_ = (Block86Data*) _userdata_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data86_->_ref_count_)) {
#line 972 "vm-creator.c"
		BoxesVMCreator* self;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data86_->_data85_->self;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block85_data_unref (_data86_->_data85_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data86_->_data85_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block86Data, _data86_);
#line 982 "vm-creator.c"
	}
}


static void ___lambda45_ (Block86Data* _data86_) {
	Block85Data* _data85_;
	BoxesVMCreator* self;
	BoxesApp* _tmp0_ = NULL;
	gulong _tmp1_ = 0UL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data85_ = _data86_->_data85_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data85_->self;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data85_->_async_data_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _data86_->handler;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 1004 "vm-creator.c"
}


static void ____lambda45__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda45_ (self);
#line 1011 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 1025 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 1034 "vm-creator.c"
		goto _state_0;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 1038 "vm-creator.c"
		goto _state_1;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 1042 "vm-creator.c"
		goto _state_2;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 3:
#line 1046 "vm-creator.c"
		goto _state_3;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 4:
#line 1050 "vm-creator.c"
		goto _state_4;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 5:
#line 1054 "vm-creator.c"
		goto _state_5;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 6:
#line 1058 "vm-creator.c"
		goto _state_6;
		default:
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 1063 "vm-creator.c"
	}
	_state_0:
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data85_ = g_slice_new0 (Block85Data);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data85_->_ref_count_ = 1;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data85_->self = boxes_vm_creator_ref (_data_->self);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data85_->_async_data_ = _data_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = FALSE;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->_tmp2_ == NULL;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp3_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data86_ = g_slice_new0 (Block86Data);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data86_->_ref_count_ = 1;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data86_->_data85_ = block85_data_ref (_data_->_data85_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data86_->handler = (gulong) 0;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = boxes_app_app;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = 0UL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = g_signal_connect_data ((GObject*) _data_->_tmp4_, "notify::default-connection", (GCallback) ____lambda45__g_object_notify, block86_data_ref (_data_->_data86_), (GClosureNotify) block86_data_unref, 0);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data86_->handler = _data_->_tmp5_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1116 "vm-creator.c"
		_state_1:
		;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block86_data_unref (_data_->_data86_);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data86_ = NULL;
#line 1123 "vm-creator.c"
	}
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 2;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media (_data_->self, boxes_vm_creator_create_vm_ready, _data_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1135 "vm-creator.c"
	_state_2:
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_finish (_data_->self, _data_->_res_, &_data_->_tmp6_, &_data_->_tmp7_, &_data_->_inner_error_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp6_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp7_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block85_data_unref (_data_->_data85_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data85_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1165 "vm-creator.c"
		} else {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1169 "vm-creator.c"
		}
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1175 "vm-creator.c"
	}
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = _data_->self->priv->_install_media;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->name;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = _data_->cancellable;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 3;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_installer_media_prepare_for_installation (_data_->_tmp8_, _data_->_tmp9_, _data_->_tmp10_, boxes_vm_creator_create_vm_ready, _data_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1195 "vm-creator.c"
	_state_3:
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_installer_media_prepare_for_installation_finish (_data_->_tmp8_, _data_->_res_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = _data_->name;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = _data_->self->priv->_install_media;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->_tmp12_->resources;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = 0LL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = osinfo_resources_get_storage (_data_->_tmp13_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = 0LL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = _data_->_tmp14_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 4;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume (_data_->self, _data_->_tmp11_, _data_->_tmp15_, boxes_vm_creator_create_vm_ready, _data_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1225 "vm-creator.c"
	_state_4:
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = boxes_vm_creator_create_target_volume_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp16_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block85_data_unref (_data_->_data85_);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data85_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1251 "vm-creator.c"
		} else {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1255 "vm-creator.c"
		}
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1261 "vm-creator.c"
	}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp17_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp17_ = _data_->name;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = _data_->title;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = _data_->volume;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = _data_->cancellable;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 5;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_config (_data_->self, _data_->_tmp17_, _data_->_tmp18_, _data_->_tmp19_, _data_->_tmp20_, boxes_vm_creator_create_vm_ready, _data_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1285 "vm-creator.c"
	_state_5:
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp21_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp21_ = boxes_vm_creator_create_domain_config_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp21_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block85_data_unref (_data_->_data85_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data85_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1313 "vm-creator.c"
		} else {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1317 "vm-creator.c"
		}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1323 "vm-creator.c"
	}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = boxes_vm_creator_get_connection (_data_->self);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp23_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp23_ = _data_->_tmp22_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp24_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp24_ = _data_->_tmp23_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp25_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp25_ = _data_->config;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp26_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp26_ = gvir_connection_create_domain (_data_->_tmp24_, _data_->_tmp25_, &_data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp27_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp27_ = _data_->_tmp26_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp24_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->domain = _data_->_tmp27_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block85_data_unref (_data_->_data85_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data85_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1375 "vm-creator.c"
		} else {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1379 "vm-creator.c"
		}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1385 "vm-creator.c"
	}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = boxes_libvirt_broker_get_default ();
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = _data_->_tmp28_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = boxes_app_app;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = boxes_app_get_default_source (_data_->_tmp30_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = _data_->_tmp31_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = boxes_app_app;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = boxes_app_get_default_connection (_data_->_tmp33_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = _data_->_tmp34_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = _data_->_tmp35_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = _data_->domain;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 6;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_libvirt_broker_add_domain (_data_->_tmp29_, _data_->_tmp32_, _data_->_tmp36_, _data_->_tmp37_, boxes_vm_creator_create_vm_ready, _data_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1433 "vm-creator.c"
	_state_6:
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = boxes_libvirt_broker_add_domain_finish (_data_->_tmp29_, _data_->_res_, &_data_->_inner_error_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp39_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp39_ = _data_->_tmp38_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp36_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp29_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _data_->_tmp39_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->domain);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block85_data_unref (_data_->_data85_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data85_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1473 "vm-creator.c"
		} else {
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1477 "vm-creator.c"
		}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1483 "vm-creator.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp40_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp40_ = _data_->machine;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_libvirt_machine_set_vm_creator (_data_->_tmp40_, _data_->self);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->machine;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block85_data_unref (_data_->_data85_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data85_ = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1511 "vm-creator.c"
	} else {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1515 "vm-creator.c"
	}
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block85_data_unref (_data_->_data85_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data85_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1541 "vm-creator.c"
	} else {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1545 "vm-creator.c"
	}
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1551 "vm-creator.c"
}


static Block87Data* block87_data_ref (Block87Data* _data87_) {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data87_->_ref_count_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data87_;
#line 1560 "vm-creator.c"
}


static void block87_data_unref (void * _userdata_) {
	Block87Data* _data87_;
	_data87_ = (Block87Data*) _userdata_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data87_->_ref_count_)) {
#line 1569 "vm-creator.c"
		BoxesVMCreator* self;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data87_->self;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data87_->machine);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block87Data, _data87_);
#line 1579 "vm-creator.c"
	}
}


static Block88Data* block88_data_ref (Block88Data* _data88_) {
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data88_->_ref_count_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data88_;
#line 1589 "vm-creator.c"
}


static void block88_data_unref (void * _userdata_) {
	Block88Data* _data88_;
	_data88_ = (Block88Data*) _userdata_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data88_->_ref_count_)) {
#line 1598 "vm-creator.c"
		BoxesVMCreator* self;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data88_->_data87_->self;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data88_->window);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block87_data_unref (_data88_->_data87_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data88_->_data87_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block88Data, _data88_);
#line 1610 "vm-creator.c"
	}
}


static void ___lambda46_ (Block88Data* _data88_) {
	Block87Data* _data87_;
	BoxesVMCreator* self;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	BoxesAppWindow* _tmp5_ = NULL;
	gulong _tmp6_ = 0UL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data87_ = _data88_->_data87_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data87_->self;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _data88_->window;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp2_ != BOXES_UI_STATE_COLLECTION) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 1639 "vm-creator.c"
	}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _data88_->window;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _data87_->machine;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_app_window_select_item (_tmp3_, (BoxesCollectionItem*) _tmp4_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _data88_->window;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _data88_->signal_id;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp5_, _tmp6_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return;
#line 1655 "vm-creator.c"
}


static void ____lambda46__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda46_ (self);
#line 1662 "vm-creator.c"
}


static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed ((BoxesVMCreator*) self, _sender, pspec);
#line 1669 "vm-creator.c"
}


static void boxes_vm_creator_real_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, gint64 access_last_time, GError** error) {
	Block87Data* _data87_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	BoxesLibvirtMachine* _tmp13_ = NULL;
	gulong _tmp14_ = 0UL;
	gint64 _tmp15_ = 0LL;
	gint64 _tmp16_ = 0LL;
	BoxesLibvirtMachine* _tmp19_ = NULL;
	BoxesBoxConfig* _tmp20_ = NULL;
	GError * _inner_error_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data87_ = g_slice_new0 (Block87Data);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data87_->_ref_count_ = 1;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data87_->self = boxes_vm_creator_ref (self);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data87_->machine);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data87_->machine = _tmp1_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = boxes_vm_creator_get_express_install (self);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _tmp2_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_tmp3_) {
#line 1708 "vm-creator.c"
		Block88Data* _data88_;
		BoxesApp* _tmp4_ = NULL;
		BoxesAppWindow* _tmp5_ = NULL;
		BoxesAppWindow* _tmp6_ = NULL;
		BoxesAppWindow* _tmp7_ = NULL;
		BoxesAppWindow* _tmp8_ = NULL;
		gulong _tmp9_ = 0UL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data88_ = g_slice_new0 (Block88Data);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data88_->_ref_count_ = 1;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data88_->_data87_ = block87_data_ref (_data87_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data88_->signal_id = (gulong) 0;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = boxes_app_app;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = boxes_app_get_main_window (_tmp4_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = _tmp5_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data88_->window = _tmp7_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = _data88_->window;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = g_signal_connect_data ((GObject*) _tmp8_, "notify::ui-state", (GCallback) ____lambda46__g_object_notify, block88_data_ref (_data88_), (GClosureNotify) block88_data_unref, 0);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data88_->signal_id = _tmp9_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block88_data_unref (_data88_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data88_ = NULL;
#line 1744 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp10_ = NULL;
		GVirDomain* _tmp11_ = NULL;
		GVirDomain* _tmp12_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _data87_->machine;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = boxes_libvirt_machine_get_domain (_tmp10_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = _tmp11_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_start (_tmp12_, (guint) 0, &_inner_error_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_propagate_error (error, _inner_error_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			block87_data_unref (_data87_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data87_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return;
#line 1767 "vm-creator.c"
		}
	}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp13_ = _data87_->machine;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp14_ = g_signal_connect ((GObject*) _tmp13_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, self);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->state_changed_id = _tmp14_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp16_ = access_last_time;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp16_ > ((gint64) 0)) {
#line 1780 "vm-creator.c"
		gint64 _tmp17_ = 0LL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp17_ = access_last_time;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _tmp17_;
#line 1786 "vm-creator.c"
	} else {
		gint64 _tmp18_ = 0LL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp18_ = g_get_real_time ();
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _tmp18_;
#line 1793 "vm-creator.c"
	}
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp19_ = _data87_->machine;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp20_ = ((BoxesMachine*) _tmp19_)->config;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_box_config_set_access_last_time (_tmp20_, _tmp15_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block87_data_unref (_data87_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data87_ = NULL;
#line 1805 "vm-creator.c"
}


void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, gint64 access_last_time, GError** error) {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->launch_vm (self, machine, access_last_time, error);
#line 1814 "vm-creator.c"
}


static void boxes_vm_creator_real_continue_installation_data_free (gpointer _data) {
	BoxesVmCreatorContinueInstallationData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorContinueInstallationData, _data_);
#line 1827 "vm-creator.c"
}


static void boxes_vm_creator_real_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorContinueInstallationData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorContinueInstallationData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_real_continue_installation);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_real_continue_installation_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = machine;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_continue_installation_co (_data_);
#line 1856 "vm-creator.c"
}


static void boxes_vm_creator_real_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
	BoxesVmCreatorContinueInstallationData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1864 "vm-creator.c"
}


static void boxes_vm_creator_continue_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorContinueInstallationData* _data_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_continue_installation_co (_data_);
#line 1878 "vm-creator.c"
}


static gboolean boxes_vm_creator_real_continue_installation_co (BoxesVmCreatorContinueInstallationData* _data_) {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 1887 "vm-creator.c"
		goto _state_0;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 1891 "vm-creator.c"
		goto _state_1;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 1895 "vm-creator.c"
		goto _state_2;
		default:
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 1900 "vm-creator.c"
	}
	_state_0:
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_media_manager_get_instance ();
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->machine;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp2_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_media_manager_create_installer_media_from_config (_data_->_tmp1_, _data_->_tmp4_, boxes_vm_creator_continue_installation_ready, _data_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1929 "vm-creator.c"
	_state_1:
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = boxes_media_manager_create_installer_media_from_config_finish (_data_->_tmp1_, _data_->_res_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_install_media (_data_->self, _data_->_tmp6_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp1_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->machine;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp7_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = 0U;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = boxes_vm_configurator_get_num_reboots (_data_->_tmp9_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_num_reboots (_data_->self, _data_->_tmp10_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = _data_->machine;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = boxes_libvirt_machine_get_domain (_data_->_tmp11_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = gvir_domain_get_name (_data_->_tmp13_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = g_strdup (_data_->_tmp14_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp15_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = _data_->self->priv->_install_media;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp16_ == NULL) {
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:93: Could not find needed install media to continue in" \
"stallation, give up on automatic installation");
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = _data_->machine;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_set_post_install_config (_data_->self, _data_->_tmp17_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2005 "vm-creator.c"
		} else {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2009 "vm-creator.c"
		}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2015 "vm-creator.c"
	}
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = _data_->self->priv->_install_media;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = _data_->_tmp18_->device_file;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = FALSE;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = g_file_test (_data_->_tmp19_, G_FILE_TEST_EXISTS);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_data_->_tmp20_) {
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = _data_->self->priv->_install_media;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = _data_->_tmp21_->device_file;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = _data_->machine;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp23_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp25_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp25_ = _data_->_tmp24_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:99: Source installer media '%s' no longer exists. Dele" \
"ting machine '%s'..", _data_->_tmp22_, _data_->_tmp25_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp26_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp26_ = boxes_app_app;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp27_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp27_ = _data_->machine;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_app_delete_machine (_data_->_tmp26_, (BoxesMachine*) _data_->_tmp27_, TRUE);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2069 "vm-creator.c"
		} else {
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2073 "vm-creator.c"
		}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2079 "vm-creator.c"
	}
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = _data_->self->priv->_install_media;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = _data_->name;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_installer_media_prepare_to_continue_installation (_data_->_tmp28_, _data_->_tmp29_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = _data_->machine;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = 0UL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = g_signal_connect ((GObject*) _data_->_tmp30_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, _data_->self);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->state_changed_id = _data_->_tmp31_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = _data_->machine;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_libvirt_machine_set_vm_creator (_data_->_tmp32_, _data_->self);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = _data_->machine;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed (_data_->self, (GObject*) _data_->_tmp33_, NULL);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = _data_->machine;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = 0;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = boxes_machine_get_state ((BoxesMachine*) _data_->_tmp35_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = 0;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = _data_->_tmp36_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp37_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp38_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp38_ = _data_->machine;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp39_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp39_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp38_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp40_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp40_ = _data_->_tmp39_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp41_ = FALSE;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp41_ = boxes_vm_configurator_is_install_config (_data_->_tmp40_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp34_ = _data_->_tmp41_;
#line 2145 "vm-creator.c"
	} else {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp34_ = FALSE;
#line 2149 "vm-creator.c"
	}
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp34_) {
#line 2153 "vm-creator.c"
		{
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp42_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp42_ = _data_->machine;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp43_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp43_ = boxes_libvirt_machine_get_domain (_data_->_tmp42_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp44_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp44_ = _data_->_tmp43_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_state_ = 2;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start_async (_data_->_tmp44_, (guint) 0, NULL, boxes_vm_creator_continue_installation_ready, _data_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 2173 "vm-creator.c"
			_state_2:
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start_finish (_data_->_tmp44_, _data_->_res_, &_data_->_inner_error_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2179 "vm-creator.c"
				goto __catch109_g_error;
			}
		}
		goto __finally109;
		__catch109_g_error:
		{
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->e = _data_->_inner_error_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_inner_error_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp45_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp45_ = _data_->machine;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp46_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp46_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp45_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp47_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp47_ = _data_->_tmp46_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp48_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp48_ = _data_->e;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp49_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp49_ = _data_->_tmp48_->message;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_warning ("vm-creator.vala:117: Failed to start '%s': %s", _data_->_tmp47_, _data_->_tmp49_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_error_free0 (_data_->e);
#line 2214 "vm-creator.c"
		}
		__finally109:
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_data_->name);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_clear_error (&_data_->_inner_error_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 2227 "vm-creator.c"
		}
	}
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2236 "vm-creator.c"
	} else {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2240 "vm-creator.c"
	}
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2246 "vm-creator.c"
}


void boxes_vm_creator_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->continue_installation (self, machine, _callback_, _user_data_);
#line 2253 "vm-creator.c"
}


void boxes_vm_creator_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->continue_installation_finish (self, _res_);
#line 2260 "vm-creator.c"
}


static Block89Data* block89_data_ref (Block89Data* _data89_) {
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data89_->_ref_count_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data89_;
#line 2269 "vm-creator.c"
}


static void block89_data_unref (void * _userdata_) {
	Block89Data* _data89_;
	_data89_ = (Block89Data*) _userdata_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data89_->_ref_count_)) {
#line 2278 "vm-creator.c"
		BoxesVMCreator* self;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data89_->self;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data89_->machine);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block89Data, _data89_);
#line 2288 "vm-creator.c"
	}
}


static void ____lambda51_ (Block89Data* _data89_) {
	BoxesVMCreator* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data89_->self;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:171: Live box deletion cancelled. Invoking post instal" \
"lation setup...");
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _data89_->machine;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_post_install_config (self, _tmp0_);
#line 2304 "vm-creator.c"
}


static void _____lambda51__boxes_app_undo_notify_callback (gpointer self) {
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	____lambda51_ (self);
#line 2311 "vm-creator.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 2318 "vm-creator.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_list_free (self);
#line 2327 "vm-creator.c"
}


static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec) {
	Block89Data* _data89_;
	GObject* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	BoxesLibvirtMachine* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	gboolean _tmp7_ = FALSE;
	BoxesLibvirtMachine* _tmp13_ = NULL;
	BoxesMachineMachineState _tmp14_ = 0;
	BoxesMachineMachineState _tmp15_ = 0;
	BoxesLibvirtMachine* _tmp19_ = NULL;
	BoxesMachineMachineState _tmp20_ = 0;
	BoxesMachineMachineState _tmp21_ = 0;
	BoxesLibvirtMachine* _tmp25_ = NULL;
	GVirDomain* domain = NULL;
	BoxesLibvirtMachine* _tmp26_ = NULL;
	GVirDomain* _tmp27_ = NULL;
	GVirDomain* _tmp28_ = NULL;
	GVirDomain* _tmp29_ = NULL;
	BoxesLibvirtMachine* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	GError * _inner_error_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (object != NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data89_ = g_slice_new0 (Block89Data);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data89_->_ref_count_ = 1;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data89_->self = boxes_vm_creator_ref (self);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = object;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp0_) : NULL);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data89_->machine = _tmp1_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _data89_->machine;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_machine_get_is_on ((BoxesMachine*) _tmp2_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _tmp3_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp4_) {
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block89_data_unref (_data89_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data89_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2386 "vm-creator.c"
	}
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _data89_->machine;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = boxes_machine_get_deleted ((BoxesMachine*) _tmp5_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = _tmp6_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp7_) {
#line 2396 "vm-creator.c"
		BoxesLibvirtMachine* _tmp8_ = NULL;
		gulong _tmp9_ = 0UL;
		BoxesLibvirtMachine* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = _data89_->machine;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = self->priv->state_changed_id;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _data89_->machine;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp10_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = _tmp11_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:129: '%s' was deleted, no need for post-installation s" \
"etup on it", _tmp12_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block89_data_unref (_data89_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data89_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2422 "vm-creator.c"
	}
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp13_ = _data89_->machine;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp14_ = boxes_machine_get_state ((BoxesMachine*) _tmp13_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp15_ = _tmp14_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp15_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 2432 "vm-creator.c"
		BoxesLibvirtMachine* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _data89_->machine;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp17_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp16_);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp18_ = _tmp17_;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:136: '%s' has saved state, no need for post-installati" \
"on setup on it", _tmp18_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block89_data_unref (_data89_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data89_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2450 "vm-creator.c"
	}
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp19_ = _data89_->machine;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp20_ = boxes_machine_get_state ((BoxesMachine*) _tmp19_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp21_ = _tmp20_;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp21_ == BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED) {
#line 2460 "vm-creator.c"
		BoxesLibvirtMachine* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp22_ = _data89_->machine;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp23_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp22_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp24_ = _tmp23_;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:142: '%s' has forced stopped, no need for post-install" \
"ation setup on it", _tmp24_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block89_data_unref (_data89_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data89_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2478 "vm-creator.c"
	}
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp25_ = _data89_->machine;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_increment_num_reboots (self, _tmp25_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp26_ = _data89_->machine;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp27_ = boxes_libvirt_machine_get_domain (_tmp26_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp28_ = _tmp27_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp29_ = _g_object_ref0 (_tmp28_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	domain = _tmp29_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp30_ = _data89_->machine;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp31_ = boxes_vm_creator_guest_installed_os (self, _tmp30_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp31_) {
#line 2500 "vm-creator.c"
		BoxesLibvirtMachine* _tmp32_ = NULL;
		BoxesInstallerMedia* _tmp33_ = NULL;
		BoxesLibvirtMachine* _tmp39_ = NULL;
		gulong _tmp40_ = 0UL;
		BoxesApp* _tmp41_ = NULL;
		BoxesLibvirtMachine* _tmp42_ = NULL;
		BoxesLibvirtMachine* _tmp43_ = NULL;
		BoxesLibvirtMachine* _tmp44_ = NULL;
		BoxesLibvirtMachine* _tmp45_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp32_ = _data89_->machine;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_set_post_install_config (self, _tmp32_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp33_ = self->priv->_install_media;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_clean_up (_tmp33_);
#line 2518 "vm-creator.c"
		{
			GVirDomain* _tmp34_ = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp34_ = domain;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start (_tmp34_, (guint) 0, &_inner_error_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2527 "vm-creator.c"
				goto __catch110_g_error;
			}
		}
		goto __finally110;
		__catch110_g_error:
		{
			GError* _error_ = NULL;
			GVirDomain* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			GError* _tmp37_ = NULL;
			const gchar* _tmp38_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_error_ = _inner_error_;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_inner_error_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp35_ = domain;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp36_ = gvir_domain_get_name (_tmp35_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp37_ = _error_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp38_ = _tmp37_->message;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_warning ("vm-creator.vala:155: Failed to start domain '%s': %s", _tmp36_, _tmp38_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_error_free0 (_error_);
#line 2555 "vm-creator.c"
		}
		__finally110:
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (domain);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			block89_data_unref (_data89_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data89_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_clear_error (&_inner_error_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return;
#line 2572 "vm-creator.c"
		}
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp39_ = _data89_->machine;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp40_ = self->priv->state_changed_id;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp39_, _tmp40_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp41_ = boxes_app_app;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp42_ = _data89_->machine;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_app_notify_machine_installed (_tmp41_, (BoxesMachine*) _tmp42_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp43_ = _data89_->machine;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_libvirt_machine_set_vm_creator (_tmp43_, NULL);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp44_ = _data89_->machine;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_schedule_autosave ((BoxesMachine*) _tmp44_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp45_ = _data89_->machine;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_try_create_snapshot (self, _tmp45_, NULL, NULL);
#line 2598 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp46_ = NULL;
		GVirConfigDomain* _tmp47_ = NULL;
		GVirConfigDomain* _tmp48_ = NULL;
		gboolean _tmp49_ = FALSE;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp46_ = _data89_->machine;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp47_ = boxes_libvirt_machine_get_domain_config (_tmp46_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp48_ = _tmp47_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp49_ = boxes_vm_configurator_is_live_config (_tmp48_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp49_) {
#line 2614 "vm-creator.c"
			BoxesLibvirtMachine* _tmp50_ = NULL;
			gulong _tmp51_ = 0UL;
			BoxesInstallerMedia* _tmp52_ = NULL;
			GList* items = NULL;
			BoxesLibvirtMachine* _tmp53_ = NULL;
			BoxesCollectionItem* _tmp54_ = NULL;
			BoxesAppUndoNotifyCallback undo_notify_callback = NULL;
			void* undo_notify_callback_target = NULL;
			GDestroyNotify undo_notify_callback_target_destroy_notify = NULL;
			gchar* msg = NULL;
			const gchar* _tmp55_ = NULL;
			BoxesLibvirtMachine* _tmp56_ = NULL;
			const gchar* _tmp57_ = NULL;
			const gchar* _tmp58_ = NULL;
			gchar* _tmp59_ = NULL;
			BoxesApp* _tmp60_ = NULL;
			GList* _tmp61_ = NULL;
			const gchar* _tmp62_ = NULL;
			BoxesAppUndoNotifyCallback _tmp63_ = NULL;
			void* _tmp63__target = NULL;
			GDestroyNotify _tmp63__target_destroy_notify = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp50_ = _data89_->machine;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp51_ = self->priv->state_changed_id;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_signal_handler_disconnect ((GObject*) _tmp50_, _tmp51_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp52_ = self->priv->_install_media;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_installer_media_clean_up (_tmp52_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			items = NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp53_ = _data89_->machine;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp54_ = _g_object_ref0 ((BoxesCollectionItem*) _tmp53_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			items = g_list_append (items, _tmp54_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback = _____lambda51__boxes_app_undo_notify_callback;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target = block89_data_ref (_data89_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target_destroy_notify = block89_data_unref;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp55_ = _ ("Live box '%s' has been deleted automatically.");
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp56_ = _data89_->machine;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp57_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp56_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp58_ = _tmp57_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp59_ = g_strdup_printf (_tmp55_, _tmp58_);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			msg = _tmp59_;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp60_ = boxes_app_app;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp61_ = items;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			items = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp62_ = msg;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp63_ = undo_notify_callback;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp63__target = undo_notify_callback_target;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp63__target_destroy_notify = undo_notify_callback_target_destroy_notify;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target_destroy_notify = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_app_delete_machines_undoable (_tmp60_, _tmp61_, _tmp62_, _tmp63_, _tmp63__target, _tmp63__target_destroy_notify);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (msg);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			(undo_notify_callback_target_destroy_notify == NULL) ? NULL : (undo_notify_callback_target_destroy_notify (undo_notify_callback_target), NULL);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback = NULL;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target = NULL;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target_destroy_notify = NULL;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			__g_list_free__g_object_unref0_0 (items);
#line 2702 "vm-creator.c"
		} else {
			{
				GVirDomain* _tmp64_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp64_ = domain;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				gvir_domain_start (_tmp64_, (guint) 0, &_inner_error_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2712 "vm-creator.c"
					goto __catch111_g_error;
				}
			}
			goto __finally111;
			__catch111_g_error:
			{
				GError* _error_ = NULL;
				GVirDomain* _tmp65_ = NULL;
				const gchar* _tmp66_ = NULL;
				GError* _tmp67_ = NULL;
				const gchar* _tmp68_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_error_ = _inner_error_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_inner_error_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp65_ = domain;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp66_ = gvir_domain_get_name (_tmp65_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp67_ = _error_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp68_ = _tmp67_->message;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_warning ("vm-creator.vala:181: Failed to start domain '%s': %s", _tmp66_, _tmp68_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_error_free0 (_error_);
#line 2740 "vm-creator.c"
			}
			__finally111:
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (domain);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				block89_data_unref (_data89_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data89_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_clear_error (&_inner_error_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return;
#line 2757 "vm-creator.c"
			}
		}
	}
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (domain);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block89_data_unref (_data89_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data89_ = NULL;
#line 2767 "vm-creator.c"
}


static void boxes_vm_creator_try_create_snapshot_data_free (gpointer _data) {
	BoxesVmCreatorTryCreateSnapshotData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorTryCreateSnapshotData, _data_);
#line 2780 "vm-creator.c"
}


static void boxes_vm_creator_try_create_snapshot (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorTryCreateSnapshotData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorTryCreateSnapshotData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_try_create_snapshot);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_try_create_snapshot_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = machine;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_try_create_snapshot_co (_data_);
#line 2809 "vm-creator.c"
}


static void boxes_vm_creator_try_create_snapshot_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
	BoxesVmCreatorTryCreateSnapshotData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2817 "vm-creator.c"
}


static void boxes_vm_creator_try_create_snapshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorTryCreateSnapshotData* _data_;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_try_create_snapshot_co (_data_);
#line 2831 "vm-creator.c"
}


static gboolean boxes_vm_creator_try_create_snapshot_co (BoxesVmCreatorTryCreateSnapshotData* _data_) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 2840 "vm-creator.c"
		goto _state_0;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 2844 "vm-creator.c"
		goto _state_1;
		default:
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 2849 "vm-creator.c"
	}
	_state_0:
	{
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp0_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp0_ = _data_->machine;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_libvirt_machine_create_snapshot (_data_->_tmp0_, "Just installed ", boxes_vm_creator_try_create_snapshot_ready, _data_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2863 "vm-creator.c"
		_state_1:
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp1_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp1_ = boxes_libvirt_machine_create_snapshot_finish (_data_->_tmp0_, _data_->_res_, &_data_->_inner_error_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp2_ = NULL;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp2_ = _data_->_tmp1_;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->_tmp2_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2877 "vm-creator.c"
			goto __catch112_g_error;
		}
	}
	goto __finally112;
	__catch112_g_error:
	{
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_inner_error_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp3_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp3_ = _data_->machine;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp3_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = _data_->_error_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp7_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp7_ = _data_->_tmp6_->message;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:190: Failed to create snapshot for domain '%s': %s", _data_->_tmp5_, _data_->_tmp7_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_data_->_error_);
#line 2912 "vm-creator.c"
	}
	__finally112:
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_data_->_inner_error_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2923 "vm-creator.c"
	}
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2929 "vm-creator.c"
	} else {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2933 "vm-creator.c"
	}
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2939 "vm-creator.c"
}


void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachine* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:195: Setting post-installation configuration on '%s'", _tmp2_);
#line 2960 "vm-creator.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp3_ = NULL;
		GVirDomain* _tmp4_ = NULL;
		GVirDomain* _tmp5_ = NULL;
		GVirConfigDomain* _tmp6_ = NULL;
		GVirConfigDomain* _tmp7_ = NULL;
		BoxesInstallerMedia* _tmp8_ = NULL;
		BoxesLibvirtMachine* _tmp9_ = NULL;
		GVirDomain* _tmp10_ = NULL;
		GVirDomain* _tmp11_ = NULL;
		GVirConfigDomain* _tmp12_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = machine;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = boxes_libvirt_machine_get_domain (_tmp3_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = _tmp4_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = gvir_domain_get_config (_tmp5_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		config = _tmp6_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2985 "vm-creator.c"
			goto __catch113_g_error;
		}
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = config;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = self->priv->_install_media;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_post_install_setup (_tmp7_, _tmp8_);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = machine;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = boxes_libvirt_machine_get_domain (_tmp9_);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = _tmp10_;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = config;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp11_, _tmp12_, &_inner_error_);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (config);
#line 3008 "vm-creator.c"
			goto __catch113_g_error;
		}
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (config);
#line 3013 "vm-creator.c"
	}
	goto __finally113;
	__catch113_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = machine;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp13_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _tmp14_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _error_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp17_ = _tmp16_->message;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:201: Failed to set post-install configuration on '%s':" \
" %s", _tmp15_, _tmp17_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 3042 "vm-creator.c"
	}
	__finally113:
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 3053 "vm-creator.c"
	}
}


static void boxes_vm_creator_real_create_domain_config_data_free (gpointer _data) {
	BoxesVmCreatorCreateDomainConfigData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateDomainConfigData, _data_);
#line 3075 "vm-creator.c"
}


static void boxes_vm_creator_real_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainConfigData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GVirStorageVol* _tmp5_ = NULL;
	GVirStorageVol* _tmp6_ = NULL;
	GCancellable* _tmp7_ = NULL;
	GCancellable* _tmp8_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateDomainConfigData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_real_create_domain_config);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_real_create_domain_config_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = name;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = title;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _tmp4_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = volume;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _tmp6_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->cancellable = _tmp8_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_create_domain_config_co (_data_);
#line 3134 "vm-creator.c"
}


static GVirConfigDomain* boxes_vm_creator_real_create_domain_config_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirConfigDomain* result;
	BoxesVmCreatorCreateDomainConfigData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 3145 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3155 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainConfigData* _data_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_create_domain_config_co (_data_);
#line 3169 "vm-creator.c"
}


static gboolean boxes_vm_creator_real_create_domain_config_co (BoxesVmCreatorCreateDomainConfigData* _data_) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 3178 "vm-creator.c"
		goto _state_0;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 3182 "vm-creator.c"
		goto _state_1;
		default:
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 3187 "vm-creator.c"
	}
	_state_0:
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->cancellable;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_connection_get_capabilities_async (_data_->_tmp2_, _data_->_tmp3_, boxes_vm_creator_create_domain_config_ready, _data_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3212 "vm-creator.c"
	_state_1:
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = gvir_connection_get_capabilities_finish (_data_->_tmp2_, _data_->_res_, &_data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->caps = _data_->_tmp5_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3236 "vm-creator.c"
		} else {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3240 "vm-creator.c"
		}
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3246 "vm-creator.c"
	}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->volume;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = gvir_storage_vol_get_path (_data_->_tmp7_, &_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->_tmp8_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3270 "vm-creator.c"
		} else {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3274 "vm-creator.c"
		}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3280 "vm-creator.c"
	}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->self->priv->_install_media;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = _data_->caps;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = boxes_vm_configurator_create_domain_config (_data_->_tmp9_, _data_->_tmp6_, _data_->_tmp10_, &_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp11_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3308 "vm-creator.c"
		} else {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3312 "vm-creator.c"
		}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3318 "vm-creator.c"
	}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = _data_->config;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->name;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_name (_data_->_tmp12_, _data_->_tmp13_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = _data_->config;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = _data_->title;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_title (_data_->_tmp14_, _data_->_tmp15_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->config;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3348 "vm-creator.c"
	} else {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3352 "vm-creator.c"
	}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3366 "vm-creator.c"
	} else {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3370 "vm-creator.c"
	}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3376 "vm-creator.c"
}


void boxes_vm_creator_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->create_domain_config (self, name, title, volume, cancellable, _callback_, _user_data_);
#line 3383 "vm-creator.c"
}


GVirConfigDomain* boxes_vm_creator_create_domain_config_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return BOXES_VM_CREATOR_GET_CLASS (self)->create_domain_config_finish (self, _res_, error);
#line 3390 "vm-creator.c"
}


static gchar* string_slice (const gchar* self, glong start, glong end) {
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	glong _tmp2_ = 0L;
	glong _tmp5_ = 0L;
	gboolean _tmp8_ = FALSE;
	glong _tmp9_ = 0L;
	gboolean _tmp12_ = FALSE;
	glong _tmp13_ = 0L;
	glong _tmp16_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	gchar* _tmp21_ = NULL;
#line 1328 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1329 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1329 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1329 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1330 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp2_ = start;
#line 1330 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp2_ < ((glong) 0)) {
#line 3423 "vm-creator.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
#line 1331 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1331 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp4_ = start;
#line 1331 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		start = _tmp3_ + _tmp4_;
#line 3432 "vm-creator.c"
	}
#line 1333 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp5_ = end;
#line 1333 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp5_ < ((glong) 0)) {
#line 3438 "vm-creator.c"
		glong _tmp6_ = 0L;
		glong _tmp7_ = 0L;
#line 1334 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp6_ = string_length;
#line 1334 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp7_ = end;
#line 1334 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		end = _tmp6_ + _tmp7_;
#line 3447 "vm-creator.c"
	}
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp9_ = start;
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp9_ >= ((glong) 0)) {
#line 3453 "vm-creator.c"
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp10_ = start;
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp11_ = string_length;
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp10_ <= _tmp11_;
#line 3462 "vm-creator.c"
	} else {
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp8_ = FALSE;
#line 3466 "vm-creator.c"
	}
#line 1336 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp8_, NULL);
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp13_ = end;
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	if (_tmp13_ >= ((glong) 0)) {
#line 3474 "vm-creator.c"
		glong _tmp14_ = 0L;
		glong _tmp15_ = 0L;
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp14_ = end;
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp12_ = _tmp14_ <= _tmp15_;
#line 3483 "vm-creator.c"
	} else {
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
		_tmp12_ = FALSE;
#line 3487 "vm-creator.c"
	}
#line 1337 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp12_, NULL);
#line 1338 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp16_ = start;
#line 1338 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp17_ = end;
#line 1338 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp16_ <= _tmp17_, NULL);
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp18_ = start;
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp19_ = end;
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp20_ = start;
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp21_ = g_strndup (((gchar*) self) + _tmp18_, (gsize) (_tmp19_ - _tmp20_));
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp21_;
#line 1339 "/jhbuild/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 3509 "vm-creator.c"
}


static void boxes_vm_creator_real_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title) {
	gchar* _vala_base_name = NULL;
	gchar* _vala_base_title = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	OsinfoOs* _tmp4_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _tmp0_->label;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_vala_base_title);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_vala_base_title = _tmp2_;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _tmp3_->os;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp4_ != NULL) {
#line 3537 "vm-creator.c"
		BoxesInstallerMedia* _tmp5_ = NULL;
		OsinfoOs* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		BoxesInstallerMedia* _tmp10_ = NULL;
		OsinfoMedia* _tmp11_ = NULL;
		const gchar* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		gint _tmp28_ = 0;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = self->priv->_install_media;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = _tmp5_->os;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp6_);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = _tmp7_;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = g_strdup (_tmp8_);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_name);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_vala_base_name = _tmp9_;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = self->priv->_install_media;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = _tmp10_->os_media;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp11_ != NULL) {
#line 3568 "vm-creator.c"
			OsinfoOsVariantList* variants = NULL;
			BoxesInstallerMedia* _tmp12_ = NULL;
			OsinfoMedia* _tmp13_ = NULL;
			OsinfoOsVariantList* _tmp14_ = NULL;
			OsinfoOsVariantList* _tmp15_ = NULL;
			gint _tmp16_ = 0;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp12_ = self->priv->_install_media;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp13_ = _tmp12_->os_media;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp14_ = osinfo_media_get_os_variants (_tmp13_);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			variants = _tmp14_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp15_ = variants;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp16_ = osinfo_list_get_length ((OsinfoList*) _tmp15_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_tmp16_ > 0) {
#line 3589 "vm-creator.c"
				const gchar* _tmp17_ = NULL;
				OsinfoOsVariantList* _tmp18_ = NULL;
				OsinfoEntity* _tmp19_ = NULL;
				gchar* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				gchar* _tmp22_ = NULL;
				gchar* _tmp23_ = NULL;
				gchar* _tmp24_ = NULL;
				gchar* _tmp25_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp17_ = _vala_base_name;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp18_ = variants;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp19_ = osinfo_list_get_nth ((OsinfoList*) _tmp18_, 0);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_get (_tmp19_, "id", &_tmp20_, NULL);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp21_ = _tmp20_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp22_ = _tmp21_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp23_ = g_strconcat ("-", _tmp22_, NULL);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp24_ = _tmp23_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp25_ = g_strconcat (_tmp17_, _tmp24_, NULL);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_vala_base_name);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_vala_base_name = _tmp25_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_tmp24_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_tmp22_);
#line 3625 "vm-creator.c"
			}
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (variants);
#line 3629 "vm-creator.c"
		}
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp26_ = _vala_base_name;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp27_ = strlen (_tmp26_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp28_ = _tmp27_;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp28_ > 12) {
#line 3639 "vm-creator.c"
			const gchar* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp29_ = _vala_base_name;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp30_ = string_slice (_tmp29_, (glong) 0, (glong) 12);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_vala_base_name);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_vala_base_name = _tmp30_;
#line 3650 "vm-creator.c"
		}
	} else {
		gchar* _tmp31_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp31_ = g_strdup ("boxes-unknown");
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_name);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_vala_base_name = _tmp31_;
#line 3660 "vm-creator.c"
	}
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (base_name) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*base_name = _vala_base_name;
#line 3666 "vm-creator.c"
	} else {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_name);
#line 3670 "vm-creator.c"
	}
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (base_title) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*base_title = _vala_base_title;
#line 3676 "vm-creator.c"
	} else {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_title);
#line 3680 "vm-creator.c"
	}
}


void boxes_vm_creator_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->create_domain_base_name_and_title (self, base_name, base_title);
#line 3690 "vm-creator.c"
}


static void boxes_vm_creator_increment_num_reboots (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	guint _tmp0_ = 0U;
	GError * _inner_error_ = NULL;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_num_reboots;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_num_reboots (self, _tmp0_ + 1);
#line 3705 "vm-creator.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirDomain* _tmp3_ = NULL;
		GVirConfigDomain* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		BoxesInstallerMedia* _tmp6_ = NULL;
		guint _tmp7_ = 0U;
		BoxesLibvirtMachine* _tmp8_ = NULL;
		GVirDomain* _tmp9_ = NULL;
		GVirDomain* _tmp10_ = NULL;
		GVirConfigDomain* _tmp11_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = machine;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = _tmp2_;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = gvir_domain_get_config (_tmp3_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		config = _tmp4_;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3731 "vm-creator.c"
			goto __catch114_g_error;
		}
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = config;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = self->priv->_install_media;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = self->priv->_num_reboots;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_set_num_reboots (_tmp5_, _tmp6_, _tmp7_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = machine;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = boxes_libvirt_machine_get_domain (_tmp8_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _tmp9_;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = config;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp10_, _tmp11_, &_inner_error_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (config);
#line 3756 "vm-creator.c"
			goto __catch114_g_error;
		}
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (config);
#line 3761 "vm-creator.c"
	}
	goto __finally114;
	__catch114_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = machine;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp12_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _tmp13_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _error_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _tmp15_->message;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:246: Failed to update configuration on '%s': %s", _tmp14_, _tmp16_);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 3790 "vm-creator.c"
	}
	__finally114:
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 3801 "vm-creator.c"
	}
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 3809 "vm-creator.c"
}


static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	gboolean result = FALSE;
	GVirStorageVol* volume = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVol* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (machine != NULL, FALSE);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	volume = _tmp3_;
#line 3835 "vm-creator.c"
	{
		gboolean _tmp4_ = FALSE;
		BoxesInstallerMedia* _tmp5_ = NULL;
		OsinfoMedia* _tmp6_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = self->priv->_install_media;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = _tmp5_->os_media;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp6_ != NULL) {
#line 3846 "vm-creator.c"
			BoxesLibvirtMachine* _tmp7_ = NULL;
			GVirConfigDomain* _tmp8_ = NULL;
			GVirConfigDomain* _tmp9_ = NULL;
			gboolean _tmp10_ = FALSE;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp7_ = machine;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp8_ = boxes_libvirt_machine_get_domain_config (_tmp7_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp9_ = _tmp8_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp10_ = boxes_vm_configurator_is_install_config (_tmp9_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp4_ = _tmp10_;
#line 3861 "vm-creator.c"
		} else {
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp4_ = FALSE;
#line 3865 "vm-creator.c"
		}
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp4_) {
#line 3869 "vm-creator.c"
			guint _tmp11_ = 0U;
			BoxesInstallerMedia* _tmp12_ = NULL;
			OsinfoMedia* _tmp13_ = NULL;
			gint _tmp14_ = 0;
			gint _tmp15_ = 0;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp11_ = self->priv->_num_reboots;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp12_ = self->priv->_install_media;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp13_ = _tmp12_->os_media;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_get (_tmp13_, "installer-reboots", &_tmp14_, NULL);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp15_ = _tmp14_;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			result = _tmp11_ == ((guint) _tmp15_);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (volume);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return result;
#line 3891 "vm-creator.c"
		} else {
			GVirStorageVolInfo* info = NULL;
			GVirStorageVol* _tmp16_ = NULL;
			GVirStorageVolInfo* _tmp17_ = NULL;
			GVirStorageVolInfo* _tmp18_ = NULL;
			guint64 _tmp19_ = 0ULL;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp16_ = volume;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp17_ = gvir_storage_vol_get_info (_tmp16_, &_inner_error_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			info = _tmp17_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3906 "vm-creator.c"
				goto __catch115_g_error;
			}
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp18_ = info;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp19_ = _tmp18_->allocation;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			result = _tmp19_ >= ((guint64) OSINFO_MEBIBYTES);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			__vala_GVirStorageVolInfo_free0 (info);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (volume);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return result;
#line 3921 "vm-creator.c"
		}
	}
	goto __finally115;
	__catch115_g_error:
	{
		GError* _error_ = NULL;
		GVirStorageVol* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		GError* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp20_ = volume;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp21_ = gvir_storage_vol_get_name (_tmp20_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp22_ = _error_;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp23_ = _tmp22_->message;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:263: Failed to get information from volume '%s': %s", _tmp21_, _tmp23_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		result = FALSE;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (volume);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return result;
#line 3954 "vm-creator.c"
	}
	__finally115:
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (volume);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_clear_error (&_inner_error_);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3965 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData, _data_);
#line 3976 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_domain_name_and_title_from_media);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_domain_name_and_title_from_media_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 3995 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** name, gchar** title, GError** error) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 4005 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (name) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*name = _data_->name;
#line 4013 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 4017 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (title) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*title = _data_->title;
#line 4025 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 4029 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = NULL;
#line 4033 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 4047 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_) {
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 4056 "vm-creator.c"
		goto _state_0;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 4060 "vm-creator.c"
		goto _state_1;
		default:
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 4065 "vm-creator.c"
	}
	_state_0:
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_base_name_and_title (_data_->self, &_data_->_tmp0_, &_data_->_tmp1_);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_name);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->base_name = _data_->_tmp0_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_title);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->base_title = _data_->_tmp1_;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = g_strdup (_data_->base_name);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp2_;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = g_strdup (_data_->base_title);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp3_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = boxes_vm_creator_get_connection (_data_->self);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_ensure_storage_pool (_data_->_tmp6_, boxes_vm_creator_create_domain_name_and_title_from_media_ready, _data_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4116 "vm-creator.c"
	_state_1:
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = boxes_ensure_storage_pool_finish (_data_->_res_, &_data_->_inner_error_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp8_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_title);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_name);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4144 "vm-creator.c"
		} else {
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4148 "vm-creator.c"
		}
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4154 "vm-creator.c"
	}
	{
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->i = 2;
#line 4159 "vm-creator.c"
		{
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp9_ = TRUE;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			while (TRUE) {
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp9_) {
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp10_ = 0;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp10_ = _data_->i;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->i = _data_->_tmp10_ + 1;
#line 4173 "vm-creator.c"
				}
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp9_ = FALSE;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp13_ = NULL;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp13_ = boxes_vm_creator_get_connection (_data_->self);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp14_ = NULL;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp14_ = _data_->_tmp13_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp15_ = NULL;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp15_ = _data_->_tmp14_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp16_ = NULL;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp16_ = _data_->name;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp17_ = NULL;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp17_ = gvir_connection_find_domain_by_name (_data_->_tmp15_, _data_->_tmp16_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp18_ = NULL;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp18_ = _data_->_tmp17_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp19_ = FALSE;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp19_ = _data_->_tmp18_ != NULL;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->_tmp18_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->_tmp15_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp19_) {
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp12_ = TRUE;
#line 4213 "vm-creator.c"
				} else {
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp20_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp20_ = boxes_vm_creator_get_connection (_data_->self);
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp21_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp21_ = _data_->_tmp20_;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp22_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp22_ = _data_->_tmp21_;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp23_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp23_ = _data_->title;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp24_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp24_ = gvir_connection_find_domain_by_name (_data_->_tmp22_, _data_->_tmp23_);
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp25_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp25_ = _data_->_tmp24_;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp12_ = _data_->_tmp25_ != NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp25_);
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp22_);
#line 4245 "vm-creator.c"
				}
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp12_) {
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp11_ = TRUE;
#line 4251 "vm-creator.c"
				} else {
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp26_ = NULL;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp26_ = _data_->name;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp27_ = NULL;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp27_ = gvir_storage_pool_get_volume (_data_->pool, _data_->_tmp26_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp28_ = NULL;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp28_ = _data_->_tmp27_;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp11_ = _data_->_tmp28_ != NULL;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp28_);
#line 4269 "vm-creator.c"
				}
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp11_) {
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					break;
#line 4275 "vm-creator.c"
				}
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp29_ = NULL;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp29_ = g_strconcat (_data_->base_name, "-", NULL);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp30_ = NULL;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp30_ = _data_->_tmp29_;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp31_ = 0;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp31_ = _data_->i;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp32_ = NULL;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp32_ = g_strdup_printf ("%i", _data_->_tmp31_);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp33_ = NULL;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp33_ = _data_->_tmp32_;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp34_ = NULL;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp34_ = g_strconcat (_data_->_tmp30_, _data_->_tmp33_, NULL);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->name);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->name = _data_->_tmp34_;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp33_);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp30_);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp35_ = NULL;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp35_ = g_strconcat (_data_->base_title, " ", NULL);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp36_ = NULL;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp36_ = _data_->_tmp35_;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp37_ = 0;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp37_ = _data_->i;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp38_ = NULL;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp38_ = g_strdup_printf ("%i", _data_->_tmp37_);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp39_ = NULL;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp39_ = _data_->_tmp38_;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp40_ = NULL;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp40_ = g_strconcat (_data_->_tmp36_, _data_->_tmp39_, NULL);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->title);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->title = _data_->_tmp40_;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp39_);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp36_);
#line 4341 "vm-creator.c"
			}
		}
	}
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_title);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_name);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4355 "vm-creator.c"
	} else {
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4359 "vm-creator.c"
	}
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4365 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_data_free (gpointer _data) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateTargetVolumeData, _data_);
#line 4380 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gint64 _tmp3_ = 0LL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateTargetVolumeData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_target_volume);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_target_volume_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = name;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = storage;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->storage = _tmp3_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 4414 "vm-creator.c"
}


static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirStorageVol* result;
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 4425 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4435 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 4449 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_) {
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 4458 "vm-creator.c"
		goto _state_0;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 4462 "vm-creator.c"
		goto _state_1;
		default:
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 4467 "vm-creator.c"
	}
	_state_0:
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_ensure_storage_pool (_data_->_tmp2_, boxes_vm_creator_create_target_volume_ready, _data_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4488 "vm-creator.c"
	_state_1:
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_ensure_storage_pool_finish (_data_->_res_, &_data_->_inner_error_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp4_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4512 "vm-creator.c"
		} else {
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4516 "vm-creator.c"
		}
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4522 "vm-creator.c"
	}
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->name;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = 0LL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->storage;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = boxes_vm_configurator_create_volume_config (_data_->_tmp5_, _data_->_tmp6_, &_data_->_inner_error_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp7_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4550 "vm-creator.c"
		} else {
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4554 "vm-creator.c"
		}
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4560 "vm-creator.c"
	}
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = _data_->name;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:290: Creating volume '%s'..", _data_->_tmp8_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->pool;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = NULL;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = _data_->config;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = NULL;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = gvir_storage_pool_create_volume (_data_->_tmp9_, _data_->_tmp10_, &_data_->_inner_error_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp11_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4596 "vm-creator.c"
		} else {
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4600 "vm-creator.c"
		}
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4606 "vm-creator.c"
	}
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = _data_->name;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:292: Created volume '%s'.", _data_->_tmp12_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->volume;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4624 "vm-creator.c"
	} else {
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4628 "vm-creator.c"
	}
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4644 "vm-creator.c"
	} else {
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4648 "vm-creator.c"
	}
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4654 "vm-creator.c"
}


BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4669 "vm-creator.c"
}


void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value) {
	BoxesInstallerMedia* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = value;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->_install_media = _tmp1_;
#line 4686 "vm-creator.c"
}


gboolean boxes_vm_creator_get_express_install (BoxesVMCreator* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesInstallerMedia* _tmp1_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = self->priv->_install_media;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_UNATTENDED_INSTALLER)) {
#line 4700 "vm-creator.c"
		BoxesInstallerMedia* _tmp2_ = NULL;
		BoxesUnattendedSetupBox* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = self->priv->_install_media;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_UNATTENDED_INSTALLER) ? ((BoxesUnattendedInstaller*) _tmp2_) : NULL)->setup_box;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = boxes_unattended_setup_box_get_express_install (_tmp3_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = _tmp4_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp0_ = _tmp5_;
#line 4715 "vm-creator.c"
	} else {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp0_ = FALSE;
#line 4719 "vm-creator.c"
	}
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4725 "vm-creator.c"
}


GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self) {
	GVirConnection* result;
	BoxesApp* _tmp0_ = NULL;
	GVirConnection* _tmp1_ = NULL;
	GVirConnection* _tmp2_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_app_get_default_connection (_tmp0_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp2_;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4746 "vm-creator.c"
}


static guint boxes_vm_creator_get_num_reboots (BoxesVMCreator* self) {
	guint result;
	guint _tmp0_ = 0U;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_num_reboots;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4761 "vm-creator.c"
}


static void boxes_vm_creator_set_num_reboots (BoxesVMCreator* self, guint value) {
	guint _tmp0_ = 0U;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = value;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->_num_reboots = _tmp0_;
#line 4773 "vm-creator.c"
}


static void boxes_value_vm_creator_init (GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	value->data[0].v_pointer = NULL;
#line 4780 "vm-creator.c"
}


static void boxes_value_vm_creator_free_value (GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (value->data[0].v_pointer) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (value->data[0].v_pointer);
#line 4789 "vm-creator.c"
	}
}


static void boxes_value_vm_creator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (src_value->data[0].v_pointer) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = boxes_vm_creator_ref (src_value->data[0].v_pointer);
#line 4799 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = NULL;
#line 4803 "vm-creator.c"
	}
}


static gpointer boxes_value_vm_creator_peek_pointer (const GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 4811 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (collect_values[0].v_pointer) {
#line 4818 "vm-creator.c"
		BoxesVMCreator* object;
		object = collect_values[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (object->parent_instance.g_class == NULL) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4825 "vm-creator.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4829 "vm-creator.c"
		}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = boxes_vm_creator_ref (object);
#line 4833 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 4837 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 4841 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesVMCreator** object_p;
	object_p = collect_values[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!object_p) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 4852 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!value->data[0].v_pointer) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = NULL;
#line 4858 "vm-creator.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = value->data[0].v_pointer;
#line 4862 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = boxes_vm_creator_ref (value->data[0].v_pointer);
#line 4866 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 4870 "vm-creator.c"
}


GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecVMCreator* spec;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return G_PARAM_SPEC (spec);
#line 4884 "vm-creator.c"
}


gpointer boxes_value_get_vm_creator (const GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 4893 "vm-creator.c"
}


void boxes_value_set_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_ref (value->data[0].v_pointer);
#line 4913 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 4917 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 4923 "vm-creator.c"
	}
}


void boxes_value_take_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 4942 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 4946 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 4952 "vm-creator.c"
	}
}


static void boxes_vm_creator_class_init (BoxesVMCreatorClass * klass) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->finalize = boxes_vm_creator_finalize;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_type_class_add_private (klass, sizeof (BoxesVMCreatorPrivate));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->launch_vm = boxes_vm_creator_real_launch_vm;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->continue_installation = boxes_vm_creator_real_continue_installation;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->continue_installation_finish = boxes_vm_creator_real_continue_installation_finish;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->create_domain_config = boxes_vm_creator_real_create_domain_config;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->create_domain_config_finish = boxes_vm_creator_real_create_domain_config_finish;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	((BoxesVMCreatorClass *) klass)->create_domain_base_name_and_title = boxes_vm_creator_real_create_domain_base_name_and_title;
#line 4976 "vm-creator.c"
}


static void boxes_vm_creator_instance_init (BoxesVMCreator * self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv = BOXES_VM_CREATOR_GET_PRIVATE (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->ref_count = 1;
#line 4985 "vm-creator.c"
}


static void boxes_vm_creator_finalize (BoxesVMCreator* obj) {
	BoxesVMCreator * self;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_VM_CREATOR, BoxesVMCreator);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handlers_destroy (self);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp0_ != NULL) {
#line 5000 "vm-creator.c"
		BoxesInstallerMedia* _tmp1_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = self->priv->_install_media;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_clean_up (_tmp1_);
#line 5006 "vm-creator.c"
	}
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 5010 "vm-creator.c"
}


GType boxes_vm_creator_get_type (void) {
	static volatile gsize boxes_vm_creator_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_vm_creator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_vm_creator_init, boxes_value_vm_creator_free_value, boxes_value_vm_creator_copy_value, boxes_value_vm_creator_peek_pointer, "p", boxes_value_vm_creator_collect_value, "p", boxes_value_vm_creator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesVMCreatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_vm_creator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesVMCreator), 0, (GInstanceInitFunc) boxes_vm_creator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_vm_creator_type_id;
		boxes_vm_creator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesVMCreator", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_vm_creator_type_id__volatile, boxes_vm_creator_type_id);
	}
	return boxes_vm_creator_type_id__volatile;
}


gpointer boxes_vm_creator_ref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&self->ref_count);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return instance;
#line 5035 "vm-creator.c"
}


void boxes_vm_creator_unref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		BOXES_VM_CREATOR_GET_CLASS (self)->finalize (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 5048 "vm-creator.c"
	}
}



